@@ -19,6 +19,7 @@ from homeassistant.components import (
     input_number,
     light,
     media_player,
+    number,
     timer,
     vacuum,
 )
@@ -613,9 +614,10 @@ async def async_api_adjust_volume_step(
     """Process an adjust volume step request."""
     # media_player volume up/down service does not support specifying steps
     # each component handles it differently e.g. via config.
-    # This workaround will simply call the volume up/Volume down the amount of steps asked for
-    # When no steps are called in the request, Alexa sends a default of 10 steps which for most
-    # purposes is too high. The default  is set 1 in this case.
+    # This workaround will simply call the volume up/Volume down the amount of
+    # steps asked for. When no steps are called in the request, Alexa sends
+    # a default of 10 steps which for most purposes is too high. The default
+    # is set 1 in this case.
     entity = directive.entity
     volume_int = int(directive.payload["volumeSteps"])
     is_default = bool(directive.payload["volumeStepsDefault"])
@@ -1020,8 +1022,9 @@ async def async_api_disarm(
     data = {ATTR_ENTITY_ID: entity.entity_id}
     response = directive.response()
 
-    # Per Alexa Documentation: If you receive a Disarm directive, and the system is already disarmed,
-    # respond with a success response, not an error response.
+    # Per Alexa Documentation: If you receive a Disarm directive, and the
+    # system is already disarmed, respond with a success response,
+    # not an error response.
     if entity.state == STATE_ALARM_DISARMED:
         return response
 
@@ -1136,7 +1139,8 @@ async def async_api_adjust_mode(
     Only supportedModes with ordered=True support the adjustMode directive.
     """
 
-    # Currently no supportedModes are configured with ordered=True to support this request.
+    # Currently no supportedModes are configured with ordered=True
+    # to support this request.
     raise AlexaInvalidDirectiveError(DIRECTIVE_NOT_SUPPORTED)
 
 
@@ -1282,6 +1286,14 @@ async def async_api_set_range(
         max_value = float(entity.attributes[input_number.ATTR_MAX])
         data[input_number.ATTR_VALUE] = min(max_value, max(min_value, range_value))
 
+    # Input Number Value
+    elif instance == f"{number.DOMAIN}.{number.ATTR_VALUE}":
+        range_value = float(range_value)
+        service = number.SERVICE_SET_VALUE
+        min_value = float(entity.attributes[number.ATTR_MIN])
+        max_value = float(entity.attributes[number.ATTR_MAX])
+        data[number.ATTR_VALUE] = min(max_value, max(min_value, range_value))
+
     # Vacuum Fan Speed
     elif instance == f"{vacuum.DOMAIN}.{vacuum.ATTR_FAN_SPEED}":
         service = vacuum.SERVICE_SET_FAN_SPEED
@@ -1413,6 +1425,17 @@ async def async_api_adjust_range(
             max_value, max(min_value, range_delta + current)
         )
 
+    # Number Value
+    elif instance == f"{number.DOMAIN}.{number.ATTR_VALUE}":
+        range_delta = float(range_delta)
+        service = number.SERVICE_SET_VALUE
+        min_value = float(entity.attributes[number.ATTR_MIN])
+        max_value = float(entity.attributes[number.ATTR_MAX])
+        current = float(entity.state)
+        data[number.ATTR_VALUE] = response_value = min(
+            max_value, max(min_value, range_delta + current)
+        )
+
     # Vacuum Fan Speed
     elif instance == f"{vacuum.DOMAIN}.{vacuum.ATTR_FAN_SPEED}":
         range_delta = int(range_delta)
@@ -1483,7 +1506,9 @@ async def async_api_changechannel(
     data = {
         ATTR_ENTITY_ID: entity.entity_id,
         media_player.const.ATTR_MEDIA_CONTENT_ID: channel,
-        media_player.const.ATTR_MEDIA_CONTENT_TYPE: media_player.const.MEDIA_TYPE_CHANNEL,
+        media_player.const.ATTR_MEDIA_CONTENT_TYPE: (
+            media_player.const.MEDIA_TYPE_CHANNEL
+        ),
     }
 
     await hass.services.async_call(
