@@ -1,4 +1,7 @@
-"""A Bluetooth passive coordinator that collects data from advertisements but can also poll."""
+"""A Bluetooth passive coordinator.
+
+Receives data from advertisements but can also poll.
+"""
 from __future__ import annotations
 
 from collections.abc import Callable, Coroutine
@@ -12,7 +15,7 @@ from homeassistant.helpers.debounce import Debouncer
 from homeassistant.util.dt import monotonic_time_coarse
 
 from . import BluetoothChange, BluetoothScanningMode, BluetoothServiceInfoBleak
-from .passive_update_processor import PassiveBluetoothProcessorCoordinator
+from .passive_update_coordinator import PassiveBluetoothDataUpdateCoordinator
 
 POLL_DEFAULT_COOLDOWN = 10
 POLL_DEFAULT_IMMEDIATE = True
@@ -20,32 +23,40 @@ POLL_DEFAULT_IMMEDIATE = True
 _T = TypeVar("_T")
 
 
-class ActiveBluetoothProcessorCoordinator(
-    Generic[_T], PassiveBluetoothProcessorCoordinator[_T]
+class ActiveBluetoothDataUpdateCoordinator(
+    PassiveBluetoothDataUpdateCoordinator, Generic[_T]
 ):
-    """
-    A coordinator that parses passive data from advertisements but can also poll.
+    """A coordinator that receives passive data from advertisements but can also poll.
+
+    Unlike the passive processor coordinator, this coordinator does call a parser
+    method to parse the data from the advertisement.
 
     Every time an advertisement is received, needs_poll_method is called to work
     out if a poll is needed. This should return True if it is and False if it is
     not needed.
 
-    def needs_poll_method(svc_info: BluetoothServiceInfoBleak, last_poll: float | None) -> bool:
+    def needs_poll_method(
+        svc_info: BluetoothServiceInfoBleak,
+        last_poll: float | None
+    ) -> bool:
         return True
 
-    If there has been no poll since HA started, `last_poll` will be None. Otherwise it is
-    the number of seconds since one was last attempted.
+    If there has been no poll since HA started, `last_poll` will be None.
+    Otherwise it is the number of seconds since one was last attempted.
 
     If a poll is needed, the coordinator will call poll_method. This is a coroutine.
-    It should return the same type of data as your update_method. The expectation is that
-    data from advertisements and from polling are being parsed and fed into a shared
-    object that represents the current state of the device.
+    It should return the same type of data as your update_method. The expectation is
+    that data from advertisements and from polling are being parsed and fed into
+    a shared object that represents the current state of the device.
 
     async def poll_method(svc_info: BluetoothServiceInfoBleak) -> YourDataType:
         return YourDataType(....)
 
     BluetoothServiceInfoBleak.device contains a BLEDevice. You should use this in
     your poll function, as it is the most efficient way to get a BleakClient.
+
+    Once the poll is complete, the coordinator will call _async_handle_bluetooth_poll
+    which needs to be implemented in the subclass.
     """
 
     def __init__(
@@ -55,7 +66,6 @@ class ActiveBluetoothProcessorCoordinator(
         *,
         address: str,
         mode: BluetoothScanningMode,
-        update_method: Callable[[BluetoothServiceInfoBleak], _T],
         needs_poll_method: Callable[[BluetoothServiceInfoBleak, float | None], bool],
         poll_method: Callable[
             [BluetoothServiceInfoBleak],
@@ -65,8 +75,12 @@ class ActiveBluetoothProcessorCoordinator(
         poll_debouncer: Debouncer[Coroutine[Any, Any, None]] | None = None,
         connectable: bool = True,
     ) -> None:
-        """Initialize the processor."""
-        super().__init__(hass, logger, address, mode, update_method, connectable)
+        """Initialize the coordinator."""
+        super().__init__(hass, logger, address, mode, connectable)
+        # It's None before the first successful update.
+        # Set type to just T to remove annoying checks that data is not None
+        # when it was already checked during setup.
+        self.data: _T = None  # type: ignore[assignment]
 
         self._needs_poll_method = needs_poll_method
         self._poll_method = poll_method
@@ -92,6 +106,8 @@ class ActiveBluetoothProcessorCoordinator(
 
     def needs_poll(self, service_info: BluetoothServiceInfoBleak) -> bool:
         """Return true if time to try and poll."""
+        if self.hass.is_stopping:
+            return False
         poll_age: float | None = None
         if self._last_poll:
             poll_age = monotonic_time_coarse() - self._last_poll
@@ -110,7 +126,7 @@ class ActiveBluetoothProcessorCoordinator(
         assert self._last_service_info
 
         try:
-            update = await self._async_poll_data(self._last_service_info)
+            self.data = await self._async_poll_data(self._last_service_info)
         except BleakError as exc:
             if self.last_poll_successful:
                 self.logger.error(
@@ -130,8 +146,12 @@ class ActiveBluetoothProcessorCoordinator(
             self.logger.debug("%s: Polling recovered")
             self.last_poll_successful = True
 
-        for processor in self._processors:
-            processor.async_handle_update(update)
+        self._async_handle_bluetooth_poll()
+
+    @callback
+    def _async_handle_bluetooth_poll(self) -> None:
+        """Handle a poll event."""
+        self.async_update_listeners()
 
     @callback
     def _async_handle_bluetooth_event(
