@@ -5,6 +5,8 @@ from contextlib import suppress
 import logging
 from typing import Any
 
+from pyfibaro.fibaro_device import DeviceModel
+
 from homeassistant.components.climate import (
     ENTITY_ID_FORMAT,
     PRESET_AWAY,
@@ -124,7 +126,7 @@ async def async_setup_entry(
 class FibaroThermostat(FibaroDevice, ClimateEntity):
     """Representation of a Fibaro Thermostat."""
 
-    def __init__(self, fibaro_device):
+    def __init__(self, fibaro_device: DeviceModel) -> None:
         """Initialize the Fibaro device."""
         super().__init__(fibaro_device)
         self._temp_sensor_device: FibaroDevice | None = None
@@ -141,26 +143,23 @@ class FibaroThermostat(FibaroDevice, ClimateEntity):
             # doing so, so we prefer the hard evidence, if there is such.
             if device.type == "com.fibaro.temperatureSensor":
                 self._temp_sensor_device = FibaroDevice(device)
-                tempunit = device.properties.unit
+                tempunit = device.unit
             elif (
                 self._temp_sensor_device is None
-                and "unit" in device.properties
-                and (
-                    "value" in device.properties
-                    or "heatingThermostatSetpoint" in device.properties
-                )
-                and device.properties.unit in ("C", "F")
+                and device.has_unit
+                and (device.value.has_value or device.has_heating_thermostat_setpoint)
+                and device.unit in ("C", "F")
             ):
                 self._temp_sensor_device = FibaroDevice(device)
-                tempunit = device.properties.unit
+                tempunit = device.unit
 
             if any(
                 action for action in TARGET_TEMP_ACTIONS if action in device.actions
             ):
                 self._target_temp_device = FibaroDevice(device)
                 self._attr_supported_features |= ClimateEntityFeature.TARGET_TEMPERATURE
-                if "unit" in device.properties:
-                    tempunit = device.properties.unit
+                if device.has_unit:
+                    tempunit = device.unit
 
             if any(action for action in OP_MODE_ACTIONS if action in device.actions):
                 self._op_mode_device = FibaroDevice(device)
@@ -176,12 +175,9 @@ class FibaroThermostat(FibaroDevice, ClimateEntity):
             self._attr_temperature_unit = UnitOfTemperature.CELSIUS
 
         if self._fan_mode_device:
-            fan_modes = (
-                self._fan_mode_device.fibaro_device.properties.supportedModes.split(",")
-            )
+            fan_modes = self._fan_mode_device.fibaro_device.supported_modes
             self._attr_fan_modes = []
             for mode in fan_modes:
-                mode = int(mode)
                 if mode not in FANMODES:
                     _LOGGER.warning("%d unknown fan mode", mode)
                     continue
@@ -190,21 +186,20 @@ class FibaroThermostat(FibaroDevice, ClimateEntity):
         self._attr_hvac_modes = [HVACMode.AUTO]  # default
         if self._op_mode_device:
             self._attr_preset_modes = []
-            self._attr_hvac_modes = []
-            prop = self._op_mode_device.fibaro_device.properties
-            if "supportedThermostatModes" in prop:
-                for mode in prop.supportedThermostatModes:
+            self._attr_hvac_modes: list[HVACMode] = []
+            device = self._op_mode_device.fibaro_device
+            if device.has_supported_thermostat_modes:
+                for mode in device.supported_thermostat_modes:
                     try:
                         self._attr_hvac_modes.append(HVACMode(mode.lower()))
                     except ValueError:
                         self._attr_preset_modes.append(mode)
             else:
-                if "supportedOperatingModes" in prop:
-                    op_modes = prop.supportedOperatingModes.split(",")
+                if device.has_supported_operating_modes:
+                    op_modes = device.supported_operating_modes
                 else:
-                    op_modes = prop.supportedModes.split(",")
+                    op_modes = device.supported_modes
                 for mode in op_modes:
-                    mode = int(mode)
                     if (
                         mode in OPMODES_HVAC
                         and (mode_ha := OPMODES_HVAC.get(mode))
@@ -236,14 +231,14 @@ class FibaroThermostat(FibaroDevice, ClimateEntity):
         siblings = self.fibaro_device.fibaro_controller.get_siblings(self.fibaro_device)
         for device in siblings:
             if device != self.fibaro_device:
-                self.controller.register(device.id, self._update_callback)
+                self.controller.register(device.fibaro_id, self._update_callback)
 
     @property
     def fan_mode(self) -> str | None:
         """Return the fan setting."""
         if not self._fan_mode_device:
             return None
-        mode = int(self._fan_mode_device.fibaro_device.properties.mode)
+        mode = self._fan_mode_device.fibaro_device.mode
         return FANMODES[mode]
 
     def set_fan_mode(self, fan_mode: str) -> None:
@@ -258,14 +253,13 @@ class FibaroThermostat(FibaroDevice, ClimateEntity):
         if not self._op_mode_device:
             return HA_OPMODES_HVAC[HVACMode.AUTO]
 
-        prop = self._op_mode_device.fibaro_device.properties
+        device = self._op_mode_device.fibaro_device
 
-        if "operatingMode" in prop:
-            return int(prop.operatingMode)
-        if "thermostatMode" in prop:
-            return prop.thermostatMode
-
-        return int(prop.mode)
+        if device.has_operating_mode:
+            return device.operating_mode
+        if device.has_thermostat_mode:
+            return device.thermostat_mode
+        return device.mode
 
     @property
     def hvac_mode(self) -> HVACMode | str | None:
@@ -288,9 +282,9 @@ class FibaroThermostat(FibaroDevice, ClimateEntity):
         if "setOperatingMode" in self._op_mode_device.fibaro_device.actions:
             self._op_mode_device.action("setOperatingMode", HA_OPMODES_HVAC[hvac_mode])
         elif "setThermostatMode" in self._op_mode_device.fibaro_device.actions:
-            prop = self._op_mode_device.fibaro_device.properties
-            if "supportedThermostatModes" in prop:
-                for mode in prop.supportedThermostatModes:
+            device = self._op_mode_device.fibaro_device
+            if device.has_supported_thermostat_modes:
+                for mode in device.supported_thermostat_modes:
                     if mode.lower() == hvac_mode:
                         self._op_mode_device.action("setThermostatMode", mode)
                         break
@@ -303,10 +297,10 @@ class FibaroThermostat(FibaroDevice, ClimateEntity):
         if not self._op_mode_device:
             return None
 
-        prop = self._op_mode_device.fibaro_device.properties
-        if "thermostatOperatingState" in prop:
+        device = self._op_mode_device.fibaro_device
+        if device.has_thermostat_operating_state:
             with suppress(ValueError):
-                return HVACAction(prop.thermostatOperatingState.lower())
+                return HVACAction(device.thermostat_operating_state.lower())
 
         return None
 
@@ -319,15 +313,15 @@ class FibaroThermostat(FibaroDevice, ClimateEntity):
         if not self._op_mode_device:
             return None
 
-        if "thermostatMode" in self._op_mode_device.fibaro_device.properties:
-            mode = self._op_mode_device.fibaro_device.properties.thermostatMode
+        if self._op_mode_device.fibaro_device.has_thermostat_mode:
+            mode = self._op_mode_device.fibaro_device.thermostat_mode
             if self.preset_modes is not None and mode in self.preset_modes:
                 return mode
             return None
-        if "operatingMode" in self._op_mode_device.fibaro_device.properties:
-            mode = int(self._op_mode_device.fibaro_device.properties.operatingMode)
+        if self._op_mode_device.fibaro_device.has_operating_mode:
+            mode = self._op_mode_device.fibaro_device.operating_mode
         else:
-            mode = int(self._op_mode_device.fibaro_device.properties.mode)
+            mode = self._op_mode_device.fibaro_device.mode
 
         if mode not in OPMODES_PRESET:
             return None
@@ -352,9 +346,9 @@ class FibaroThermostat(FibaroDevice, ClimateEntity):
         """Return the current temperature."""
         if self._temp_sensor_device:
             device = self._temp_sensor_device.fibaro_device
-            if "heatingThermostatSetpoint" in device.properties:
-                return float(device.properties.heatingThermostatSetpoint)
-            return float(device.properties.value)
+            if device.has_heating_thermostat_setpoint:
+                return device.heating_thermostat_setpoint
+            return device.value.float_value()
         return None
 
     @property
@@ -362,9 +356,9 @@ class FibaroThermostat(FibaroDevice, ClimateEntity):
         """Return the temperature we try to reach."""
         if self._target_temp_device:
             device = self._target_temp_device.fibaro_device
-            if "heatingThermostatSetpointFuture" in device.properties:
-                return float(device.properties.heatingThermostatSetpointFuture)
-            return float(device.properties.targetLevel)
+            if device.has_heating_thermostat_setpoint_future:
+                return device.heating_thermostat_setpoint_future
+            return device.target_level
         return None
 
     def set_temperature(self, **kwargs: Any) -> None:
