@@ -9,8 +9,3 @@ CONF_STILL_IMAGE_URL = "still_image_url"
 CONF_STREAM_SOURCE = "stream_source"
 CONF_FRAMERATE = "framerate"
 GET_IMAGE_TIMEOUT = 10
-
-DEFAULT_USERNAME = None
-DEFAULT_PASSWORD = None
-DEFAULT_IMAGE_URL = None
-DEFAULT_STREAM_SOURCE = None
