@@ -15,6 +15,7 @@ from homeassistant.const import (
     RESTART_EXIT_CODE,
     SERVICE_HOMEASSISTANT_RESTART,
     SERVICE_HOMEASSISTANT_STOP,
+    SERVICE_RELOAD,
     SERVICE_SAVE_PERSISTENT_STATES,
     SERVICE_TOGGLE,
     SERVICE_TURN_OFF,
@@ -40,6 +41,7 @@ SERVICE_RELOAD_CONFIG_ENTRY = "reload_config_entry"
 SERVICE_CHECK_CONFIG = "check_config"
 SERVICE_UPDATE_ENTITY = "update_entity"
 SERVICE_SET_LOCATION = "set_location"
+SERVICE_RELOAD_ALL = "reload_all"
 SCHEMA_UPDATE_ENTITY = vol.Schema({ATTR_ENTITY_ID: cv.entity_ids})
 SCHEMA_RELOAD_CONFIG_ENTRY = vol.All(
     vol.Schema(
@@ -154,7 +156,8 @@ async def async_setup(hass: ha.HomeAssistant, config: ConfigType) -> bool:  # no
             )
 
         if call.service == SERVICE_HOMEASSISTANT_STOP:
-            asyncio.create_task(hass.async_stop())
+            # Track trask in hass.data. No need to cleanup, we're stopping.
+            hass.data["homeassistant_stop"] = asyncio.create_task(hass.async_stop())
             return
 
         errors = await conf_util.async_check_ha_config_file(hass)
@@ -177,7 +180,10 @@ async def async_setup(hass: ha.HomeAssistant, config: ConfigType) -> bool:  # no
             )
 
         if call.service == SERVICE_HOMEASSISTANT_RESTART:
-            asyncio.create_task(hass.async_stop(RESTART_EXIT_CODE))
+            # Track trask in hass.data. No need to cleanup, we're stopping.
+            hass.data["homeassistant_stop"] = asyncio.create_task(
+                hass.async_stop(RESTART_EXIT_CODE)
+            )
 
     async def async_handle_update_service(call: ha.ServiceCall) -> None:
         """Service handler for updating an entity."""
@@ -275,4 +281,50 @@ async def async_setup(hass: ha.HomeAssistant, config: ConfigType) -> bool:  # no
         schema=SCHEMA_RELOAD_CONFIG_ENTRY,
     )
 
+    async def async_handle_reload_all(call: ha.ServiceCall) -> None:
+        """Service handler for calling all integration reload services.
+
+        Calls all reload services on all active domains, which triggers the
+        reload of YAML configurations for the domain that support it.
+
+        Additionally, it also calls the `homeasssitant.reload_core_config`
+        service, as that reloads the core YAML configuration, and the
+        `frontend.reload_themes` service, as that reloads the themes.
+
+        We only do so, if there are no configuration errors.
+        """
+
+        if errors := await conf_util.async_check_ha_config_file(hass):
+            _LOGGER.error(
+                "The system cannot reload because the configuration is not valid: %s",
+                errors,
+            )
+            raise HomeAssistantError(
+                "Cannot quick reload all YAML configurations because the "
+                f"configuration is not valid: {errors}"
+            )
+
+        services = hass.services.async_services()
+        tasks = [
+            hass.services.async_call(
+                domain, SERVICE_RELOAD, context=call.context, blocking=True
+            )
+            for domain, domain_services in services.items()
+            if domain != "notify" and SERVICE_RELOAD in domain_services
+        ] + [
+            hass.services.async_call(
+                domain, service, context=call.context, blocking=True
+            )
+            for domain, service in {
+                ha.DOMAIN: SERVICE_RELOAD_CORE_CONFIG,
+                "frontend": "reload_themes",
+            }.items()
+        ]
+
+        await asyncio.gather(*tasks)
+
+    async_register_admin_service(
+        hass, ha.DOMAIN, SERVICE_RELOAD_ALL, async_handle_reload_all
+    )
+
     return True
