@@ -1,19 +1,17 @@
 """Home Assistant trigger dispatcher."""
 import importlib
 
-from homeassistant.components.automation import (
-    AutomationActionType,
-    AutomationTriggerInfo,
-)
-from homeassistant.components.device_automation.trigger import (
-    DeviceAutomationTriggerProtocol,
-)
 from homeassistant.const import CONF_PLATFORM
 from homeassistant.core import CALLBACK_TYPE, HomeAssistant
+from homeassistant.helpers.trigger import (
+    TriggerActionType,
+    TriggerInfo,
+    TriggerProtocol,
+)
 from homeassistant.helpers.typing import ConfigType
 
 
-def _get_trigger_platform(config: ConfigType) -> DeviceAutomationTriggerProtocol:
+def _get_trigger_platform(config: ConfigType) -> TriggerProtocol:
     return importlib.import_module(f"..triggers.{config[CONF_PLATFORM]}", __name__)
 
 
@@ -23,7 +21,7 @@ async def async_validate_trigger_config(
     """Validate config."""
     platform = _get_trigger_platform(config)
     if hasattr(platform, "async_validate_trigger_config"):
-        return await getattr(platform, "async_validate_trigger_config")(hass, config)
+        return await platform.async_validate_trigger_config(hass, config)
 
     return platform.TRIGGER_SCHEMA(config)
 
@@ -31,9 +29,9 @@ async def async_validate_trigger_config(
 async def async_attach_trigger(
     hass: HomeAssistant,
     config: ConfigType,
-    action: AutomationActionType,
-    automation_info: AutomationTriggerInfo,
+    action: TriggerActionType,
+    trigger_info: TriggerInfo,
 ) -> CALLBACK_TYPE:
     """Attach trigger of specified platform."""
     platform = _get_trigger_platform(config)
-    return await platform.async_attach_trigger(hass, config, action, automation_info)
+    return await platform.async_attach_trigger(hass, config, action, trigger_info)
