@@ -32,7 +32,7 @@ from homeassistant.components.climate import (
     HVACMode,
 )
 from homeassistant.config_entries import ConfigEntry
-from homeassistant.const import ATTR_TEMPERATURE, TEMP_CELSIUS, Platform
+from homeassistant.const import ATTR_TEMPERATURE, Platform, UnitOfTemperature
 from homeassistant.core import HomeAssistant, callback
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
 
@@ -114,7 +114,7 @@ async def async_setup_entry(
 class HomeKitBaseClimateEntity(HomeKitEntity, ClimateEntity):
     """The base HomeKit Controller climate entity."""
 
-    _attr_temperature_unit = TEMP_CELSIUS
+    _attr_temperature_unit = UnitOfTemperature.CELSIUS
 
     def get_characteristic_types(self) -> list[str]:
         """Define the homekit characteristics the entity cares about."""
@@ -187,8 +187,11 @@ class HomeKitHeaterCoolerEntity(HomeKitBaseClimateEntity):
         else:
             hvac_mode = TARGET_HEATER_COOLER_STATE_HOMEKIT_TO_HASS.get(state)
             _LOGGER.warning(
-                "HomeKit device %s: Setting temperature in %s mode is not supported yet;"
-                " Consider raising a ticket if you have this device and want to help us implement this feature",
+                (
+                    "HomeKit device %s: Setting temperature in %s mode is not supported"
+                    " yet; Consider raising a ticket if you have this device and want"
+                    " to help us implement this feature"
+                ),
                 self.entity_id,
                 hvac_mode,
             )
@@ -202,8 +205,11 @@ class HomeKitHeaterCoolerEntity(HomeKitBaseClimateEntity):
             return
         if hvac_mode not in {HVACMode.HEAT, HVACMode.COOL}:
             _LOGGER.warning(
-                "HomeKit device %s: Setting temperature in %s mode is not supported yet;"
-                " Consider raising a ticket if you have this device and want to help us implement this feature",
+                (
+                    "HomeKit device %s: Setting temperature in %s mode is not supported"
+                    " yet; Consider raising a ticket if you have this device and want"
+                    " to help us implement this feature"
+                ),
                 self.entity_id,
                 hvac_mode,
             )
