@@ -1,23 +1,20 @@
 """Update coordinator for HomeWizard."""
 from __future__ import annotations
 
-from datetime import timedelta
 import logging
 
 from homewizard_energy import HomeWizardEnergy
 from homewizard_energy.errors import DisabledError, RequestError
 
+from homeassistant.config_entries import ConfigEntry
 from homeassistant.core import HomeAssistant
 from homeassistant.helpers.aiohttp_client import async_get_clientsession
-from homeassistant.helpers.entity import DeviceInfo
 from homeassistant.helpers.update_coordinator import DataUpdateCoordinator, UpdateFailed
 
 from .const import DOMAIN, UPDATE_INTERVAL, DeviceResponseEntry
 
 _LOGGER = logging.getLogger(__name__)
 
-MAX_UPDATE_INTERVAL = timedelta(minutes=30)
-
 
 class HWEnergyDeviceUpdateCoordinator(DataUpdateCoordinator[DeviceResponseEntry]):
     """Gather data for the energy device."""
@@ -28,37 +25,26 @@ class HWEnergyDeviceUpdateCoordinator(DataUpdateCoordinator[DeviceResponseEntry]
     def __init__(
         self,
         hass: HomeAssistant,
-        entry_id: str,
+        entry: ConfigEntry,
         host: str,
     ) -> None:
-        """Initialize Update Coordinator."""
-
+        """Initialize update coordinator."""
         super().__init__(hass, _LOGGER, name=DOMAIN, update_interval=UPDATE_INTERVAL)
-        self.entry_id = entry_id
+        self.entry = entry
         self.api = HomeWizardEnergy(host, clientsession=async_get_clientsession(hass))
 
-    @property
-    def device_info(self) -> DeviceInfo:
-        """Return device_info."""
-        return DeviceInfo(
-            identifiers={(DOMAIN, self.data["device"].serial)},
-        )
-
     async def _async_update_data(self) -> DeviceResponseEntry:
         """Fetch all device and sensor data from api."""
-
-        # Update all properties
         try:
-            data: DeviceResponseEntry = {
-                "device": await self.api.device(),
-                "data": await self.api.data(),
-                "state": await self.api.state(),
-                "system": None,
-            }
+            data = DeviceResponseEntry(
+                device=await self.api.device(),
+                data=await self.api.data(),
+                features=await self.api.features(),
+                state=await self.api.state(),
+            )
 
-            features = await self.api.features()
-            if features.has_system:
-                data["system"] = await self.api.system()
+            if data.features.has_system:
+                data.system = await self.api.system()
 
         except RequestError as ex:
             raise UpdateFailed(ex) from ex
@@ -69,11 +55,10 @@ class HWEnergyDeviceUpdateCoordinator(DataUpdateCoordinator[DeviceResponseEntry]
 
                 # Do not reload when performing first refresh
                 if self.data is not None:
-                    await self.hass.config_entries.async_reload(self.entry_id)
+                    await self.hass.config_entries.async_reload(self.entry.entry_id)
 
             raise UpdateFailed(ex) from ex
 
-        else:
-            self.api_disabled = False
+        self.api_disabled = False
 
         return data
