@@ -4,22 +4,14 @@ from __future__ import annotations
 import logging
 from typing import Any
 
-from iaqualink.const import (
-    AQUALINK_TEMP_CELSIUS_HIGH,
-    AQUALINK_TEMP_CELSIUS_LOW,
-    AQUALINK_TEMP_FAHRENHEIT_HIGH,
-    AQUALINK_TEMP_FAHRENHEIT_LOW,
-)
-from iaqualink.device import AqualinkHeater, AqualinkPump, AqualinkSensor, AqualinkState
-
-from homeassistant.components.climate import ClimateEntity
-from homeassistant.components.climate.const import (
+from homeassistant.components.climate import (
     DOMAIN as CLIMATE_DOMAIN,
+    ClimateEntity,
     ClimateEntityFeature,
     HVACMode,
 )
 from homeassistant.config_entries import ConfigEntry
-from homeassistant.const import ATTR_TEMPERATURE, TEMP_CELSIUS, TEMP_FAHRENHEIT
+from homeassistant.const import ATTR_TEMPERATURE, UnitOfTemperature
 from homeassistant.core import HomeAssistant
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
 
@@ -55,17 +47,10 @@ class HassAqualinkThermostat(AqualinkEntity, ClimateEntity):
         """Return the name of the thermostat."""
         return self.dev.label.split(" ")[0]
 
-    @property
-    def pump(self) -> AqualinkPump:
-        """Return the pump device for the current thermostat."""
-        pump = f"{self.name.lower()}_pump"
-        return self.dev.system.devices[pump]
-
     @property
     def hvac_mode(self) -> HVACMode:
         """Return the current HVAC mode."""
-        state = AqualinkState(self.heater.state)
-        if state == AqualinkState.ON:
+        if self.dev.is_on is True:
             return HVACMode.HEAT
         return HVACMode.OFF
 
@@ -73,32 +58,28 @@ class HassAqualinkThermostat(AqualinkEntity, ClimateEntity):
     async def async_set_hvac_mode(self, hvac_mode: HVACMode) -> None:
         """Turn the underlying heater switch on or off."""
         if hvac_mode == HVACMode.HEAT:
-            await await_or_reraise(self.heater.turn_on())
+            await await_or_reraise(self.dev.turn_on())
         elif hvac_mode == HVACMode.OFF:
-            await await_or_reraise(self.heater.turn_off())
+            await await_or_reraise(self.dev.turn_off())
         else:
             _LOGGER.warning("Unknown operation mode: %s", hvac_mode)
 
     @property
     def temperature_unit(self) -> str:
         """Return the unit of measurement."""
-        if self.dev.system.temp_unit == "F":
-            return TEMP_FAHRENHEIT
-        return TEMP_CELSIUS
+        if self.dev.unit == "F":
+            return UnitOfTemperature.FAHRENHEIT
+        return UnitOfTemperature.CELSIUS
 
     @property
     def min_temp(self) -> int:
         """Return the minimum temperature supported by the thermostat."""
-        if self.temperature_unit == TEMP_FAHRENHEIT:
-            return AQUALINK_TEMP_FAHRENHEIT_LOW
-        return AQUALINK_TEMP_CELSIUS_LOW
+        return self.dev.min_temperature
 
     @property
     def max_temp(self) -> int:
         """Return the minimum temperature supported by the thermostat."""
-        if self.temperature_unit == TEMP_FAHRENHEIT:
-            return AQUALINK_TEMP_FAHRENHEIT_HIGH
-        return AQUALINK_TEMP_CELSIUS_HIGH
+        return self.dev.max_temperature
 
     @property
     def target_temperature(self) -> float:
@@ -110,21 +91,9 @@ class HassAqualinkThermostat(AqualinkEntity, ClimateEntity):
         """Set new target temperature."""
         await await_or_reraise(self.dev.set_temperature(int(kwargs[ATTR_TEMPERATURE])))
 
-    @property
-    def sensor(self) -> AqualinkSensor:
-        """Return the sensor device for the current thermostat."""
-        sensor = f"{self.name.lower()}_temp"
-        return self.dev.system.devices[sensor]
-
     @property
     def current_temperature(self) -> float | None:
         """Return the current temperature."""
-        if self.sensor.state != "":
-            return float(self.sensor.state)
+        if self.dev.current_temperature != "":
+            return float(self.dev.current_temperature)
         return None
-
-    @property
-    def heater(self) -> AqualinkHeater:
-        """Return the heater device for the current thermostat."""
-        heater = f"{self.name.lower()}_heater"
-        return self.dev.system.devices[heater]
