@@ -1,6 +1,8 @@
-"""Constants for the ISY994 Platform."""
+"""Constants for the ISY Platform."""
 import logging
 
+from pyisy.constants import PROP_ON_LEVEL, PROP_RAMP_RATE
+
 from homeassistant.components.binary_sensor import BinarySensorDeviceClass
 from homeassistant.components.climate import (
     FAN_AUTO,
@@ -58,6 +60,7 @@ DOMAIN = "isy994"
 
 MANUFACTURER = "Universal Devices, Inc"
 
+CONF_NETWORK = "network"
 CONF_IGNORE_STRING = "ignore_string"
 CONF_SENSOR_STRING = "sensor_string"
 CONF_VAR_SENSOR_STRING = "variable_sensor_string"
@@ -74,7 +77,7 @@ DEFAULT_VAR_SENSOR_STRING = "HA."
 KEY_ACTIONS = "actions"
 KEY_STATUS = "status"
 
-PLATFORMS = [
+NODE_PLATFORMS = [
     Platform.BINARY_SENSOR,
     Platform.CLIMATE,
     Platform.COVER,
@@ -84,6 +87,12 @@ PLATFORMS = [
     Platform.SENSOR,
     Platform.SWITCH,
 ]
+NODE_AUX_PROP_PLATFORMS = [
+    Platform.NUMBER,
+    Platform.SELECT,
+    Platform.SENSOR,
+    Platform.SWITCH,
+]
 PROGRAM_PLATFORMS = [
     Platform.BINARY_SENSOR,
     Platform.COVER,
@@ -91,6 +100,17 @@ PROGRAM_PLATFORMS = [
     Platform.LOCK,
     Platform.SWITCH,
 ]
+ROOT_NODE_PLATFORMS = [Platform.BUTTON]
+VARIABLE_PLATFORMS = [Platform.NUMBER, Platform.SENSOR]
+
+# Set of all platforms used by integration
+PLATFORMS = {
+    *NODE_PLATFORMS,
+    *NODE_AUX_PROP_PLATFORMS,
+    *PROGRAM_PLATFORMS,
+    *ROOT_NODE_PLATFORMS,
+    *VARIABLE_PLATFORMS,
+}
 
 SUPPORTED_BIN_SENS_CLASSES = ["moisture", "opening", "motion", "climate"]
 
@@ -98,10 +118,14 @@ SUPPORTED_BIN_SENS_CLASSES = ["moisture", "opening", "motion", "climate"]
 # (they can turn off, and report their state)
 ISY_GROUP_PLATFORM = Platform.SWITCH
 
-ISY994_ISY = "isy"
-ISY994_NODES = "isy994_nodes"
-ISY994_PROGRAMS = "isy994_programs"
-ISY994_VARIABLES = "isy994_variables"
+ISY_CONF_UUID = "uuid"
+ISY_CONF_NAME = "name"
+ISY_CONF_MODEL = "model"
+ISY_CONF_FIRMWARE = "firmware"
+
+ISY_CONN_PORT = "port"
+ISY_CONN_ADDRESS = "addr"
+ISY_CONN_TLS = "tls"
 
 FILTER_UOM = "uom"
 FILTER_STATES = "states"
@@ -162,8 +186,6 @@ UOM_INDEX = "25"
 UOM_ON_OFF = "2"
 UOM_PERCENTAGE = "51"
 
-SENSOR_AUX = "sensor_aux"
-
 # Do not use the Home Assistant consts for the states here - we're matching exact API
 # responses, not using them for Home Assistant states
 # Insteon Types: https://www.universal-devices.com/developers/wsdk/5.0.4/1_fam.xml
@@ -232,7 +254,7 @@ NODE_FILTERS: dict[Platform, dict[str, list[str]]] = {
         FILTER_STATES: ["open", "closed", "closing", "opening", "stopped"],
         FILTER_NODE_DEF_ID: ["DimmerMotorSwitch_ADV"],
         FILTER_INSTEON_TYPE: [TYPE_CATEGORY_COVER],
-        FILTER_ZWAVE_CAT: [],
+        FILTER_ZWAVE_CAT: ["106", "107"],
     },
     Platform.LIGHT: {
         FILTER_UOM: ["51"],
@@ -289,11 +311,15 @@ NODE_FILTERS: dict[Platform, dict[str, list[str]]] = {
         FILTER_ZWAVE_CAT: ["140"],
     },
 }
+NODE_AUX_FILTERS: dict[str, Platform] = {
+    PROP_ON_LEVEL: Platform.NUMBER,
+    PROP_RAMP_RATE: Platform.SELECT,
+}
 
 UOM_FRIENDLY_NAME = {
-    "1": "A",
+    "1": UnitOfElectricCurrent.AMPERE,
     UOM_ON_OFF: "",  # Binary, no unit
-    "3": f"btu/{UnitOfTime.HOURS}",
+    "3": UnitOfPower.BTU_PER_HOUR,
     "4": UnitOfTemperature.CELSIUS,
     "5": UnitOfLength.CENTIMETERS,
     "6": UnitOfVolume.CUBIC_FEET,
@@ -319,7 +345,7 @@ UOM_FRIENDLY_NAME = {
     "28": UnitOfMass.KILOGRAMS,
     "29": "kV",
     "30": UnitOfPower.KILO_WATT,
-    "31": "kPa",
+    "31": UnitOfPressure.KPA,
     "32": UnitOfSpeed.KILOMETERS_PER_HOUR,
     "33": UnitOfEnergy.KILO_WATT_HOUR,
     "34": "liedu",
