@@ -13,16 +13,18 @@ from homeassistant.const import (
     CONF_TYPE,
     CONF_UNIT_OF_MEASUREMENT,
     SERVICE_RELOAD,
+    Platform,
 )
 from homeassistant.core import HomeAssistant, ServiceCall, callback
 from homeassistant.helpers import entity_platform
 import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.entity_platform import async_get_platforms
 import homeassistant.helpers.entity_registry as er
+from homeassistant.helpers.issue_registry import IssueSeverity, async_create_issue
 from homeassistant.helpers.service import entity_service_call
 
-from .const import _LOGGER, DOMAIN, ISY994_ISY
-from .util import unique_ids_for_config_entry_id
+from .const import _LOGGER, CONF_NETWORK, DOMAIN, ISY_CONF_NAME
+from .util import _async_cleanup_registry_entries
 
 # Common Services for All Platforms:
 SERVICE_SYSTEM_QUERY = "system_query"
@@ -181,10 +183,11 @@ def async_setup_services(hass: HomeAssistant) -> None:  # noqa: C901
         """Handle a system query service call."""
         address = service.data.get(CONF_ADDRESS)
         isy_name = service.data.get(CONF_ISY)
-
+        entity_registry = er.async_get(hass)
         for config_entry_id in hass.data[DOMAIN]:
-            isy = hass.data[DOMAIN][config_entry_id][ISY994_ISY]
-            if isy_name and isy_name != isy.configuration["name"]:
+            isy_data = hass.data[DOMAIN][config_entry_id]
+            isy = isy_data.root
+            if isy_name and isy_name != isy.conf["name"]:
                 continue
             # If an address is provided, make sure we query the correct ISY.
             # Otherwise, query the whole system on all ISY's connected.
@@ -192,14 +195,32 @@ def async_setup_services(hass: HomeAssistant) -> None:  # noqa: C901
                 _LOGGER.debug(
                     "Requesting query of device %s on ISY %s",
                     address,
-                    isy.configuration["uuid"],
+                    isy.uuid,
                 )
                 await isy.query(address)
+                async_log_deprecated_service_call(
+                    hass,
+                    call=service,
+                    alternate_service="button.press",
+                    alternate_target=entity_registry.async_get_entity_id(
+                        Platform.BUTTON,
+                        DOMAIN,
+                        f"{isy.uuid}_{address}_query",
+                    ),
+                    breaks_in_ha_version="2023.5.0",
+                )
                 return
-            _LOGGER.debug(
-                "Requesting system query of ISY %s", isy.configuration["uuid"]
-            )
+            _LOGGER.debug("Requesting system query of ISY %s", isy.uuid)
             await isy.query()
+            async_log_deprecated_service_call(
+                hass,
+                call=service,
+                alternate_service="button.press",
+                alternate_target=entity_registry.async_get_entity_id(
+                    Platform.BUTTON, DOMAIN, f"{isy.uuid}_query"
+                ),
+                breaks_in_ha_version="2023.5.0",
+            )
 
     async def async_run_network_resource_service_handler(service: ServiceCall) -> None:
         """Handle a network resource service call."""
@@ -208,10 +229,11 @@ def async_setup_services(hass: HomeAssistant) -> None:  # noqa: C901
         isy_name = service.data.get(CONF_ISY)
 
         for config_entry_id in hass.data[DOMAIN]:
-            isy = hass.data[DOMAIN][config_entry_id][ISY994_ISY]
-            if isy_name and isy_name != isy.configuration["name"]:
+            isy_data = hass.data[DOMAIN][config_entry_id]
+            isy = isy_data.root
+            if isy_name and isy_name != isy.conf[ISY_CONF_NAME]:
                 continue
-            if not hasattr(isy, "networking") or isy.networking is None:
+            if isy.networking is None:
                 continue
             command = None
             if address:
@@ -220,6 +242,18 @@ def async_setup_services(hass: HomeAssistant) -> None:  # noqa: C901
                 command = isy.networking.get_by_name(name)
             if command is not None:
                 await command.run()
+                entity_registry = er.async_get(hass)
+                async_log_deprecated_service_call(
+                    hass,
+                    call=service,
+                    alternate_service="button.press",
+                    alternate_target=entity_registry.async_get_entity_id(
+                        Platform.BUTTON,
+                        DOMAIN,
+                        f"{isy.uuid}_{CONF_NETWORK}_{address}",
+                    ),
+                    breaks_in_ha_version="2023.5.0",
+                )
                 return
         _LOGGER.error(
             "Could not run network resource command; not found or enabled on the ISY"
@@ -233,8 +267,9 @@ def async_setup_services(hass: HomeAssistant) -> None:  # noqa: C901
         isy_name = service.data.get(CONF_ISY)
 
         for config_entry_id in hass.data[DOMAIN]:
-            isy = hass.data[DOMAIN][config_entry_id][ISY994_ISY]
-            if isy_name and isy_name != isy.configuration["name"]:
+            isy_data = hass.data[DOMAIN][config_entry_id]
+            isy = isy_data.root
+            if isy_name and isy_name != isy.conf["name"]:
                 continue
             program = None
             if address:
@@ -256,8 +291,9 @@ def async_setup_services(hass: HomeAssistant) -> None:  # noqa: C901
         isy_name = service.data.get(CONF_ISY)
 
         for config_entry_id in hass.data[DOMAIN]:
-            isy = hass.data[DOMAIN][config_entry_id][ISY994_ISY]
-            if isy_name and isy_name != isy.configuration["name"]:
+            isy_data = hass.data[DOMAIN][config_entry_id]
+            isy = isy_data.root
+            if isy_name and isy_name != isy.conf["name"]:
                 continue
             variable = None
             if name:
@@ -266,50 +302,43 @@ def async_setup_services(hass: HomeAssistant) -> None:  # noqa: C901
                 variable = isy.variables.vobjs[vtype].get(address)
             if variable is not None:
                 await variable.set_value(value, init)
+                entity_registry = er.async_get(hass)
+                async_log_deprecated_service_call(
+                    hass,
+                    call=service,
+                    alternate_service="number.set_value",
+                    alternate_target=entity_registry.async_get_entity_id(
+                        Platform.NUMBER,
+                        DOMAIN,
+                        f"{isy.uuid}_{address}{'_init' if init else ''}",
+                    ),
+                    breaks_in_ha_version="2023.5.0",
+                )
                 return
         _LOGGER.error("Could not set variable value; not found or enabled on the ISY")
 
     @callback
     def async_cleanup_registry_entries(service: ServiceCall) -> None:
         """Remove extra entities that are no longer part of the integration."""
-        entity_registry = er.async_get(hass)
-        config_ids = []
-        current_unique_ids: set[str] = set()
-
-        for config_entry_id in hass.data[DOMAIN]:
-            entries_for_this_config = er.async_entries_for_config_entry(
-                entity_registry, config_entry_id
-            )
-            config_ids.extend(
-                [
-                    (entity.unique_id, entity.entity_id)
-                    for entity in entries_for_this_config
-                ]
-            )
-            current_unique_ids |= unique_ids_for_config_entry_id(hass, config_entry_id)
-
-        extra_entities = [
-            entity_id
-            for unique_id, entity_id in config_ids
-            if unique_id not in current_unique_ids
-        ]
-
-        for entity_id in extra_entities:
-            if entity_registry.async_is_registered(entity_id):
-                entity_registry.async_remove(entity_id)
-
-        _LOGGER.debug(
-            (
-                "Cleaning up ISY994 Entities and devices: Config Entries: %s, Current"
-                " Entries: %s, Extra Entries Removed: %s"
-            ),
-            len(config_ids),
-            len(current_unique_ids),
-            len(extra_entities),
+        async_log_deprecated_service_call(
+            hass,
+            call=service,
+            alternate_service="homeassistant.reload_core_config",
+            alternate_target=None,
+            breaks_in_ha_version="2023.5.0",
         )
+        for config_entry_id in hass.data[DOMAIN]:
+            _async_cleanup_registry_entries(hass, config_entry_id)
 
     async def async_reload_config_entries(service: ServiceCall) -> None:
-        """Trigger a reload of all ISY994 config entries."""
+        """Trigger a reload of all ISY config entries."""
+        async_log_deprecated_service_call(
+            hass,
+            call=service,
+            alternate_service="homeassistant.reload_core_config",
+            alternate_target=None,
+            breaks_in_ha_version="2023.5.0",
+        )
         for config_entry_id in hass.data[DOMAIN]:
             hass.async_create_task(hass.config_entries.async_reload(config_entry_id))
 
@@ -447,3 +476,47 @@ def async_setup_light_services(hass: HomeAssistant) -> None:
     platform.async_register_entity_service(
         SERVICE_SET_RAMP_RATE, SERVICE_SET_RAMP_RATE_SCHEMA, "async_set_ramp_rate"
     )
+
+
+@callback
+def async_log_deprecated_service_call(
+    hass: HomeAssistant,
+    call: ServiceCall,
+    alternate_service: str,
+    alternate_target: str | None,
+    breaks_in_ha_version: str,
+) -> None:
+    """Log a warning about a deprecated service call."""
+    deprecated_service = f"{call.domain}.{call.service}"
+    alternate_target = alternate_target or "this device"
+
+    async_create_issue(
+        hass,
+        DOMAIN,
+        f"deprecated_service_{deprecated_service}",
+        breaks_in_ha_version=breaks_in_ha_version,
+        is_fixable=True,
+        is_persistent=True,
+        severity=IssueSeverity.WARNING,
+        translation_key="deprecated_service",
+        translation_placeholders={
+            "alternate_service": alternate_service,
+            "alternate_target": alternate_target,
+            "deprecated_service": deprecated_service,
+        },
+    )
+
+    alternate_text = ""
+    if alternate_target:
+        alternate_text = f' and pass it a target entity ID of "{alternate_target}"'
+
+    _LOGGER.warning(
+        (
+            'The "%s" service is deprecated and will be removed in %s; use the "%s" '
+            "service %s"
+        ),
+        deprecated_service,
+        breaks_in_ha_version,
+        alternate_service,
+        alternate_text,
+    )
