@@ -3,7 +3,7 @@ from __future__ import annotations
 
 from abc import ABC, abstractmethod
 from datetime import timedelta
-from typing import Any, TypeVar, Union
+from typing import Any, TypeVar
 
 from jellyfin_apiclient_python import JellyfinClient
 
@@ -15,10 +15,7 @@ from .const import DOMAIN, LOGGER
 
 JellyfinDataT = TypeVar(
     "JellyfinDataT",
-    bound=Union[
-        dict[str, dict[str, Any]],
-        dict[str, Any],
-    ],
+    bound=dict[str, dict[str, Any]] | dict[str, Any],
 )
 
 
