@@ -1,5 +1,7 @@
 """Constants for the LED BLE integration."""
 
+from typing import Final
+
 DOMAIN = "led_ble"
 
 DEVICE_TIMEOUT = 30
@@ -8,3 +10,5 @@ LOCAL_NAMES = {"LEDnet", "BLE-LED", "LEDBLE", "Triones", "LEDBlue"}
 UNSUPPORTED_SUB_MODEL = "LEDnetWF"
 
 UPDATE_SECONDS = 15
+
+DEFAULT_EFFECT_SPEED: Final = 50
