@@ -4,25 +4,23 @@ from __future__ import annotations
 from collections.abc import Callable
 from dataclasses import dataclass
 from datetime import datetime
-from typing import Any, Generic, Union, cast
+from typing import Any, Generic, cast
 
 from pylitterbot import FeederRobot, LitterRobot, LitterRobot4, Robot
 
 from homeassistant.components.sensor import (
-    DOMAIN as PLATFORM,
     SensorDeviceClass,
     SensorEntity,
     SensorEntityDescription,
     SensorStateClass,
 )
 from homeassistant.config_entries import ConfigEntry
-from homeassistant.const import PERCENTAGE, UnitOfMass
+from homeassistant.const import PERCENTAGE, EntityCategory, UnitOfMass
 from homeassistant.core import HomeAssistant
-from homeassistant.helpers.entity import EntityCategory
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
 
 from .const import DOMAIN
-from .entity import LitterRobotEntity, _RobotT, async_update_unique_id
+from .entity import LitterRobotEntity, _RobotT
 from .hub import LitterRobotHub
 
 
@@ -56,7 +54,7 @@ class LitterRobotSensorEntity(LitterRobotEntity[_RobotT], SensorEntity):
         if self.entity_description.should_report(self.robot):
             if isinstance(val := getattr(self.robot, self.entity_description.key), str):
                 return val.lower()
-            return cast(Union[float, datetime, None], val)
+            return cast(float | datetime | None, val)
         return None
 
     @property
@@ -71,32 +69,32 @@ ROBOT_SENSOR_MAP: dict[type[Robot], list[RobotSensorEntityDescription]] = {
     LitterRobot: [
         RobotSensorEntityDescription[LitterRobot](
             key="waste_drawer_level",
-            name="Waste Drawer",
+            name="Waste drawer",
             native_unit_of_measurement=PERCENTAGE,
             icon_fn=lambda state: icon_for_gauge_level(state, 10),
             state_class=SensorStateClass.MEASUREMENT,
         ),
         RobotSensorEntityDescription[LitterRobot](
             key="sleep_mode_start_time",
-            name="Sleep Mode Start Time",
+            name="Sleep mode start time",
             device_class=SensorDeviceClass.TIMESTAMP,
             should_report=lambda robot: robot.sleep_mode_enabled,
         ),
         RobotSensorEntityDescription[LitterRobot](
             key="sleep_mode_end_time",
-            name="Sleep Mode End Time",
+            name="Sleep mode end time",
             device_class=SensorDeviceClass.TIMESTAMP,
             should_report=lambda robot: robot.sleep_mode_enabled,
         ),
         RobotSensorEntityDescription[LitterRobot](
             key="last_seen",
-            name="Last Seen",
+            name="Last seen",
             device_class=SensorDeviceClass.TIMESTAMP,
             entity_category=EntityCategory.DIAGNOSTIC,
         ),
         RobotSensorEntityDescription[LitterRobot](
             key="status_code",
-            name="Status Code",
+            name="Status code",
             translation_key="status_code",
             entity_category=EntityCategory.DIAGNOSTIC,
             device_class=SensorDeviceClass.ENUM,
@@ -142,7 +140,7 @@ ROBOT_SENSOR_MAP: dict[type[Robot], list[RobotSensorEntityDescription]] = {
             name="Pet weight",
             native_unit_of_measurement=UnitOfMass.POUNDS,
             device_class=SensorDeviceClass.WEIGHT,
-            state_class=SensorStateClass.MEASUREMENT,
+            state_class=SensorStateClass.TOTAL,
         ),
     ],
     FeederRobot: [
@@ -171,5 +169,4 @@ async def async_setup_entry(
         if isinstance(robot, robot_type)
         for description in entity_descriptions
     ]
-    async_update_unique_id(hass, PLATFORM, entities)
     async_add_entities(entities)
