@@ -5,10 +5,9 @@ from collections.abc import Iterable
 
 import sqlalchemy
 from sqlalchemy import lambda_stmt, select
-from sqlalchemy.orm import Query
-from sqlalchemy.sql.elements import ClauseList
+from sqlalchemy.sql.elements import BooleanClauseList
 from sqlalchemy.sql.lambdas import StatementLambdaElement
-from sqlalchemy.sql.selectable import CTE, CompoundSelect
+from sqlalchemy.sql.selectable import CTE, CompoundSelect, Select
 
 from homeassistant.components.recorder.db_schema import (
     DEVICE_ID_IN_EVENT,
@@ -32,7 +31,7 @@ def _select_device_id_context_ids_sub_query(
     end_day: float,
     event_types: tuple[str, ...],
     json_quotable_device_ids: list[str],
-) -> CompoundSelect:
+) -> Select:
     """Generate a subquery to find context ids for multiple devices."""
     inner = select_events_context_id_subquery(start_day, end_day, event_types).where(
         apply_event_device_id_matchers(json_quotable_device_ids)
@@ -41,7 +40,7 @@ def _select_device_id_context_ids_sub_query(
 
 
 def _apply_devices_context_union(
-    query: Query,
+    sel: Select,
     start_day: float,
     end_day: float,
     event_types: tuple[str, ...],
@@ -54,7 +53,7 @@ def _apply_devices_context_union(
         event_types,
         json_quotable_device_ids,
     ).cte()
-    return query.union_all(
+    return sel.union_all(
         apply_events_context_hints(
             select_events_context_only()
             .select_from(devices_cte)
@@ -91,7 +90,7 @@ def devices_stmt(
 
 def apply_event_device_id_matchers(
     json_quotable_device_ids: Iterable[str],
-) -> ClauseList:
+) -> BooleanClauseList:
     """Create matchers for the device_ids in the event_data."""
     return DEVICE_ID_IN_EVENT.is_not(None) & sqlalchemy.cast(
         DEVICE_ID_IN_EVENT, sqlalchemy.Text()
