@@ -10,32 +10,29 @@ from homeassistant.components import light
 from homeassistant.config_entries import ConfigEntry
 from homeassistant.core import HomeAssistant
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
-from homeassistant.helpers.typing import ConfigType
+from homeassistant.helpers.typing import ConfigType, DiscoveryInfoType
 
 from ..mixins import async_setup_entry_helper, warn_for_legacy_schema
 from .schema import CONF_SCHEMA, MQTT_LIGHT_SCHEMA_SCHEMA
 from .schema_basic import (
     DISCOVERY_SCHEMA_BASIC,
-    PLATFORM_SCHEMA_BASIC,
     PLATFORM_SCHEMA_MODERN_BASIC,
     async_setup_entity_basic,
 )
 from .schema_json import (
     DISCOVERY_SCHEMA_JSON,
-    PLATFORM_SCHEMA_JSON,
     PLATFORM_SCHEMA_MODERN_JSON,
     async_setup_entity_json,
 )
 from .schema_template import (
     DISCOVERY_SCHEMA_TEMPLATE,
     PLATFORM_SCHEMA_MODERN_TEMPLATE,
-    PLATFORM_SCHEMA_TEMPLATE,
     async_setup_entity_template,
 )
 
 
 def validate_mqtt_light_discovery(config_value: dict[str, Any]) -> ConfigType:
-    """Validate MQTT light schema for."""
+    """Validate MQTT light schema for discovery."""
     schemas = {
         "basic": DISCOVERY_SCHEMA_BASIC,
         "json": DISCOVERY_SCHEMA_JSON,
@@ -45,19 +42,8 @@ def validate_mqtt_light_discovery(config_value: dict[str, Any]) -> ConfigType:
     return config
 
 
-def validate_mqtt_light(config_value: dict[str, Any]) -> ConfigType:
-    """Validate MQTT light schema."""
-    schemas = {
-        "basic": PLATFORM_SCHEMA_BASIC,
-        "json": PLATFORM_SCHEMA_JSON,
-        "template": PLATFORM_SCHEMA_TEMPLATE,
-    }
-    config: ConfigType = schemas[config_value[CONF_SCHEMA]](config_value)
-    return config
-
-
 def validate_mqtt_light_modern(config_value: dict[str, Any]) -> ConfigType:
-    """Validate MQTT light schema."""
+    """Validate MQTT light schema for setup from configuration.yaml."""
     schemas = {
         "basic": PLATFORM_SCHEMA_MODERN_BASIC,
         "json": PLATFORM_SCHEMA_MODERN_JSON,
@@ -101,7 +87,7 @@ async def _async_setup_entity(
     async_add_entities: AddEntitiesCallback,
     config: ConfigType,
     config_entry: ConfigEntry,
-    discovery_data: dict | None = None,
+    discovery_data: DiscoveryInfoType | None = None,
 ) -> None:
     """Set up a MQTT Light."""
     setup_entity = {
