@@ -14,7 +14,7 @@ def db_size_bytes(session: Session, database_name: str) -> float | None:
             "TABLE_SCHEMA=:database_name"
         ),
         {"database_name": database_name},
-    ).first()[0]
+    ).scalar()
 
     if size is None:
         return None
