@@ -4,6 +4,7 @@ from __future__ import annotations
 from functools import partial
 import logging
 import re
+from typing import Any
 
 from libsoundtouch.device import SoundTouchDevice
 from libsoundtouch.utils import Source
@@ -12,31 +13,26 @@ import voluptuous as vol
 from homeassistant.components import media_source
 from homeassistant.components.media_player import (
     PLATFORM_SCHEMA,
+    BrowseMedia,
     MediaPlayerDeviceClass,
     MediaPlayerEntity,
     MediaPlayerEntityFeature,
-)
-from homeassistant.components.media_player.browse_media import (
+    MediaPlayerState,
     async_process_play_media_url,
 )
-from homeassistant.components.repairs import IssueSeverity, async_create_issue
 from homeassistant.config_entries import SOURCE_IMPORT, ConfigEntry
 from homeassistant.const import (
     CONF_HOST,
     CONF_NAME,
     CONF_PORT,
     EVENT_HOMEASSISTANT_START,
-    STATE_OFF,
-    STATE_PAUSED,
-    STATE_PLAYING,
-    STATE_UNAVAILABLE,
-    STATE_UNKNOWN,
 )
 from homeassistant.core import HomeAssistant, callback
 import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.device_registry import CONNECTION_NETWORK_MAC, format_mac
 from homeassistant.helpers.entity import DeviceInfo
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
+from homeassistant.helpers.issue_registry import IssueSeverity, async_create_issue
 from homeassistant.helpers.typing import ConfigType, DiscoveryInfoType
 
 from .const import DOMAIN
@@ -44,10 +40,10 @@ from .const import DOMAIN
 _LOGGER = logging.getLogger(__name__)
 
 MAP_STATUS = {
-    "PLAY_STATE": STATE_PLAYING,
-    "BUFFERING_STATE": STATE_PLAYING,
-    "PAUSE_STATE": STATE_PAUSED,
-    "STOP_STATE": STATE_OFF,
+    "PLAY_STATE": MediaPlayerState.PLAYING,
+    "BUFFERING_STATE": MediaPlayerState.PLAYING,
+    "PAUSE_STATE": MediaPlayerState.PAUSED,
+    "STOP_STATE": MediaPlayerState.OFF,
 }
 
 ATTR_SOUNDTOUCH_GROUP = "soundtouch_group"
@@ -154,7 +150,7 @@ class SoundTouchMediaPlayer(MediaPlayerEntity):
         """Return SoundTouch device."""
         return self._device
 
-    def update(self):
+    def update(self) -> None:
         """Retrieve the latest data."""
         self._status = self._device.status()
         self._volume = self._device.volume()
@@ -166,15 +162,15 @@ class SoundTouchMediaPlayer(MediaPlayerEntity):
         return self._volume.actual / 100
 
     @property
-    def state(self):
+    def state(self) -> MediaPlayerState | None:
         """Return the state of the device."""
         if self._status is None or self._status.source == "STANDBY":
-            return STATE_OFF
+            return MediaPlayerState.OFF
 
         if self._status.source == "INVALID_SOURCE":
-            return STATE_UNKNOWN
+            return None
 
-        return MAP_STATUS.get(self._status.play_status, STATE_UNAVAILABLE)
+        return MAP_STATUS.get(self._status.play_status)
 
     @property
     def source(self):
@@ -194,47 +190,47 @@ class SoundTouchMediaPlayer(MediaPlayerEntity):
         """Boolean if volume is currently muted."""
         return self._volume.muted
 
-    def turn_off(self):
+    def turn_off(self) -> None:
         """Turn off media player."""
         self._device.power_off()
 
-    def turn_on(self):
+    def turn_on(self) -> None:
         """Turn on media player."""
         self._device.power_on()
 
-    def volume_up(self):
+    def volume_up(self) -> None:
         """Volume up the media player."""
         self._device.volume_up()
 
-    def volume_down(self):
+    def volume_down(self) -> None:
         """Volume down media player."""
         self._device.volume_down()
 
-    def set_volume_level(self, volume):
+    def set_volume_level(self, volume: float) -> None:
         """Set volume level, range 0..1."""
         self._device.set_volume(int(volume * 100))
 
-    def mute_volume(self, mute):
+    def mute_volume(self, mute: bool) -> None:
         """Send mute command."""
         self._device.mute()
 
-    def media_play_pause(self):
+    def media_play_pause(self) -> None:
         """Simulate play pause media player."""
         self._device.play_pause()
 
-    def media_play(self):
+    def media_play(self) -> None:
         """Send play command."""
         self._device.play()
 
-    def media_pause(self):
+    def media_pause(self) -> None:
         """Send media pause command to media player."""
         self._device.pause()
 
-    def media_next_track(self):
+    def media_next_track(self) -> None:
         """Send next track command."""
         self._device.next_track()
 
-    def media_previous_track(self):
+    def media_previous_track(self) -> None:
         """Send the previous track command."""
         self._device.previous_track()
 
@@ -273,7 +269,7 @@ class SoundTouchMediaPlayer(MediaPlayerEntity):
         """Album name of current playing media."""
         return self._status.album
 
-    async def async_added_to_hass(self):
+    async def async_added_to_hass(self) -> None:
         """Populate zone info which requires entity_id."""
 
         @callback
@@ -285,7 +281,9 @@ class SoundTouchMediaPlayer(MediaPlayerEntity):
             EVENT_HOMEASSISTANT_START, async_update_on_start
         )
 
-    async def async_play_media(self, media_type, media_id, **kwargs):
+    async def async_play_media(
+        self, media_type: str, media_id: str, **kwargs: Any
+    ) -> None:
         """Play a piece of media."""
         if media_source.is_media_source_id(media_id):
             play_item = await media_source.async_resolve_media(
@@ -297,7 +295,7 @@ class SoundTouchMediaPlayer(MediaPlayerEntity):
             partial(self.play_media, media_type, media_id, **kwargs)
         )
 
-    def play_media(self, media_type, media_id, **kwargs):
+    def play_media(self, media_type: str, media_id: str, **kwargs: Any) -> None:
         """Play a piece of media."""
         _LOGGER.debug("Starting media with media_id: %s", media_id)
         if re.match(r"http?://", str(media_id)):
@@ -319,7 +317,7 @@ class SoundTouchMediaPlayer(MediaPlayerEntity):
             else:
                 _LOGGER.warning("Unable to find preset with id %s", media_id)
 
-    def select_source(self, source):
+    def select_source(self, source: str) -> None:
         """Select input source."""
         if source == Source.AUX.value:
             _LOGGER.debug("Selecting source AUX")
@@ -331,8 +329,7 @@ class SoundTouchMediaPlayer(MediaPlayerEntity):
             _LOGGER.warning("Source %s is not supported", source)
 
     def create_zone(self, slaves):
-        """
-        Create a zone (multi-room)  and play on selected devices.
+        """Create a zone (multi-room)  and play on selected devices.
 
         :param slaves: slaves on which to play
 
@@ -344,10 +341,9 @@ class SoundTouchMediaPlayer(MediaPlayerEntity):
             self._device.create_zone([slave.device for slave in slaves])
 
     def remove_zone_slave(self, slaves):
-        """
-        Remove slave(s) from and existing zone (multi-room).
+        """Remove slave(s) from and existing zone (multi-room).
 
-        Zone must already exist and slaves array can not be empty.
+        Zone must already exist and slaves array cannot be empty.
         Note: If removing last slave, the zone will be deleted and you'll have
         to create a new one. You will not be able to add a new slave anymore
 
@@ -369,10 +365,9 @@ class SoundTouchMediaPlayer(MediaPlayerEntity):
                     self._device.remove_zone_slave([slave.device])
 
     def add_zone_slave(self, slaves):
-        """
-        Add slave(s) to and existing zone (multi-room).
+        """Add slave(s) to and existing zone (multi-room).
 
-        Zone must already exist and slaves array can not be empty.
+        Zone must already exist and slaves array cannot be empty.
 
         :param slaves:slaves to add
 
@@ -399,7 +394,9 @@ class SoundTouchMediaPlayer(MediaPlayerEntity):
 
         return attributes
 
-    async def async_browse_media(self, media_content_type=None, media_content_id=None):
+    async def async_browse_media(
+        self, media_content_type: str | None = None, media_content_id: str | None = None
+    ) -> BrowseMedia:
         """Implement the websocket media browsing helper."""
         return await media_source.async_browse_media(self.hass, media_content_id)
 
@@ -410,16 +407,19 @@ class SoundTouchMediaPlayer(MediaPlayerEntity):
             return None
 
         # Client devices do NOT return their siblings as part of the "slaves" list.
-        # Only the master has the full list of slaves. To compensate for this shortcoming
-        # we have to fetch the zone info from the master when the current device is a slave.
+        # Only the master has the full list of slaves. To compensate for this
+        # shortcoming we have to fetch the zone info from the master when the current
+        # device is a slave.
         # In addition to this shortcoming, libsoundtouch seems to report the "is_master"
-        # property wrong on some slaves, so the only reliable way to detect if the current
-        # devices is the master, is by comparing the master_id of the zone with the device_id.
+        # property wrong on some slaves, so the only reliable way to detect
+        # if the current devices is the master, is by comparing the master_id
+        # of the zone with the device_id.
         if zone_status.master_id == self._device.config.device_id:
             return self._build_zone_info(self.entity_id, zone_status.slaves)
 
-        # The master device has to be searched by it's ID and not IP since libsoundtouch / BOSE API
-        # do not return the IP of the master for some slave objects/responses
+        # The master device has to be searched by it's ID and not IP since
+        # libsoundtouch / BOSE API do not return the IP of the master
+        # for some slave objects/responses
         master_instance = self._get_instance_by_id(zone_status.master_id)
         if master_instance is not None:
             master_zone_status = master_instance.device.zone_status()
@@ -427,8 +427,9 @@ class SoundTouchMediaPlayer(MediaPlayerEntity):
                 master_instance.entity_id, master_zone_status.slaves
             )
 
-        # We should never end up here since this means we haven't found a master device to get the
-        # correct zone info from. In this case, assume current device is master
+        # We should never end up here since this means we haven't found a master
+        # device to get the correct zone info from. In this case,
+        # assume current device is master
         return self._build_zone_info(self.entity_id, zone_status.slaves)
 
     def _get_instance_by_ip(self, ip_address):
