@@ -20,14 +20,14 @@ import asyncio
 from collections.abc import Callable, Mapping
 import copy
 import logging
-import re
 import secrets
 import threading
 import time
 from types import MappingProxyType
-from typing import Any, Final, cast
+from typing import TYPE_CHECKING, Any, Final, cast
 
 import voluptuous as vol
+from yarl import URL
 
 from homeassistant.const import EVENT_HOMEASSISTANT_STOP
 from homeassistant.core import Event, HomeAssistant, callback
@@ -63,12 +63,16 @@ from .core import (
     STREAM_SETTINGS_NON_LL_HLS,
     IdleTimer,
     KeyFrameConverter,
+    Orientation,
     StreamOutput,
     StreamSettings,
 )
 from .diagnostics import Diagnostics
 from .hls import HlsStreamOutput, async_setup_hls
 
+if TYPE_CHECKING:
+    from homeassistant.components.camera import DynamicStreamSettings
+
 __all__ = [
     "ATTR_SETTINGS",
     "CONF_EXTRA_PART_WAIT_TIME",
@@ -82,30 +86,33 @@ __all__ = [
     "SOURCE_TIMEOUT",
     "Stream",
     "create_stream",
+    "Orientation",
 ]
 
 _LOGGER = logging.getLogger(__name__)
 
-STREAM_SOURCE_REDACT_PATTERN = [
-    (re.compile(r"//.*:.*@"), "//****:****@"),
-    (re.compile(r"\?auth=.*"), "?auth=****"),
-]
 
-
-def redact_credentials(data: str) -> str:
+def redact_credentials(url: str) -> str:
     """Redact credentials from string data."""
-    for (pattern, repl) in STREAM_SOURCE_REDACT_PATTERN:
-        data = pattern.sub(repl, data)
-    return data
+    yurl = URL(url)
+    if yurl.user is not None:
+        yurl = yurl.with_user("****")
+    if yurl.password is not None:
+        yurl = yurl.with_password("****")
+    redacted_query_params = dict.fromkeys(
+        {"auth", "user", "password"} & yurl.query.keys(), "****"
+    )
+    return str(yurl.update_query(redacted_query_params))
 
 
 def create_stream(
     hass: HomeAssistant,
     stream_source: str,
     options: Mapping[str, str | bool | float],
+    dynamic_stream_settings: DynamicStreamSettings,
     stream_label: str | None = None,
 ) -> Stream:
-    """Create a stream with the specified identfier based on the source url.
+    """Create a stream with the specified identifier based on the source url.
 
     The stream_source is typically an rtsp url (though any url accepted by ffmpeg is fine) and
     options (see STREAM_OPTIONS_SCHEMA) are converted and passed into pyav / ffmpeg.
@@ -154,6 +161,7 @@ def create_stream(
         stream_source,
         pyav_options=pyav_options,
         stream_settings=stream_settings,
+        dynamic_stream_settings=dynamic_stream_settings,
         stream_label=stream_label,
     )
     hass.data[DOMAIN][ATTR_STREAMS].append(stream)
@@ -212,7 +220,7 @@ async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool:
     filter_libav_logging()
 
     # Keep import here so that we can import stream integration without installing reqs
-    # pylint: disable=import-outside-toplevel
+    # pylint: disable-next=import-outside-toplevel
     from .recorder import async_setup_recorder
 
     hass.data[DOMAIN] = {}
@@ -229,7 +237,6 @@ async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool:
             part_target_duration=conf[CONF_PART_DURATION],
             hls_advance_part_limit=max(int(3 / conf[CONF_PART_DURATION]), 3),
             hls_part_timeout=2 * conf[CONF_PART_DURATION],
-            orientation=1,
         )
     else:
         hass.data[DOMAIN][ATTR_SETTINGS] = STREAM_SETTINGS_NON_LL_HLS
@@ -244,7 +251,7 @@ async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool:
     async def shutdown(event: Event) -> None:
         """Stop all stream workers."""
         for stream in hass.data[DOMAIN][ATTR_STREAMS]:
-            stream.keepalive = False
+            stream.dynamic_stream_settings.preload_stream = False
         if awaitables := [
             asyncio.create_task(stream.stop())
             for stream in hass.data[DOMAIN][ATTR_STREAMS]
@@ -266,6 +273,7 @@ class Stream:
         source: str,
         pyav_options: dict[str, str],
         stream_settings: StreamSettings,
+        dynamic_stream_settings: DynamicStreamSettings,
         stream_label: str | None = None,
     ) -> None:
         """Initialize a stream."""
@@ -274,14 +282,16 @@ class Stream:
         self.pyav_options = pyav_options
         self._stream_settings = stream_settings
         self._stream_label = stream_label
-        self.keepalive = False
+        self.dynamic_stream_settings = dynamic_stream_settings
         self.access_token: str | None = None
         self._start_stop_lock = asyncio.Lock()
         self._thread: threading.Thread | None = None
         self._thread_quit = threading.Event()
         self._outputs: dict[str, StreamOutput] = {}
         self._fast_restart_once = False
-        self._keyframe_converter = KeyFrameConverter(hass, stream_settings)
+        self._keyframe_converter = KeyFrameConverter(
+            hass, stream_settings, dynamic_stream_settings
+        )
         self._available: bool = True
         self._update_callback: Callable[[], None] | None = None
         self._logger = (
@@ -291,16 +301,6 @@ class Stream:
         )
         self._diagnostics = Diagnostics()
 
-    @property
-    def orientation(self) -> int:
-        """Return the current orientation setting."""
-        return self._stream_settings.orientation
-
-    @orientation.setter
-    def orientation(self, value: int) -> None:
-        """Set the stream orientation setting."""
-        self._stream_settings.orientation = value
-
     def endpoint_url(self, fmt: str) -> str:
         """Start the stream and returns a url for the output format."""
         if fmt not in self._outputs:
@@ -324,7 +324,8 @@ class Stream:
 
             async def idle_callback() -> None:
                 if (
-                    not self.keepalive or fmt == RECORDER_PROVIDER
+                    not self.dynamic_stream_settings.preload_stream
+                    or fmt == RECORDER_PROVIDER
                 ) and fmt in self._outputs:
                     await self.remove_provider(self._outputs[fmt])
                 self.check_idle()
@@ -333,6 +334,7 @@ class Stream:
                 self.hass,
                 IdleTimer(self.hass, timeout, idle_callback),
                 self._stream_settings,
+                self.dynamic_stream_settings,
             )
             self._outputs[fmt] = provider
 
@@ -403,7 +405,7 @@ class Stream:
     def _run_worker(self) -> None:
         """Handle consuming streams and restart keepalive streams."""
         # Keep import here so that we can import stream integration without installing reqs
-        # pylint: disable=import-outside-toplevel
+        # pylint: disable-next=import-outside-toplevel
         from .worker import StreamState, StreamWorkerError, stream_worker
 
         stream_state = StreamState(self.hass, self.outputs, self._diagnostics)
@@ -411,8 +413,12 @@ class Stream:
         while not self._thread_quit.wait(timeout=wait_timeout):
             start_time = time.time()
             self.hass.add_job(self._async_update_state, True)
-            self._diagnostics.set_value("keepalive", self.keepalive)
-            self._diagnostics.set_value("orientation", self.orientation)
+            self._diagnostics.set_value(
+                "keepalive", self.dynamic_stream_settings.preload_stream
+            )
+            self._diagnostics.set_value(
+                "orientation", self.dynamic_stream_settings.orientation
+            )
             self._diagnostics.increment("start_worker")
             try:
                 stream_worker(
@@ -471,7 +477,7 @@ class Stream:
         self._outputs = {}
         self.access_token = None
 
-        if not self.keepalive:
+        if not self.dynamic_stream_settings.preload_stream:
             await self._stop()
 
     async def _stop(self) -> None:
@@ -495,7 +501,7 @@ class Stream:
         """Make a .mp4 recording from a provided stream."""
 
         # Keep import here so that we can import stream integration without installing reqs
-        # pylint: disable=import-outside-toplevel
+        # pylint: disable-next=import-outside-toplevel
         from .recorder import RecorderOutput
 
         # Check for file access
@@ -532,8 +538,7 @@ class Stream:
         width: int | None = None,
         height: int | None = None,
     ) -> bytes | None:
-        """
-        Fetch an image from the Stream and return it as a jpeg in bytes.
+        """Fetch an image from the Stream and return it as a jpeg in bytes.
 
         Calls async_get_image from KeyFrameConverter. async_get_image should only be
         called directly from the main loop and not from an executor thread as it uses
