@@ -1,8 +1,6 @@
 """Support for Tilt Hydrometers."""
 from __future__ import annotations
 
-from typing import Optional, Union
-
 from tilt_ble import DeviceClass, DeviceKey, SensorUpdate, Units
 
 from homeassistant import config_entries
@@ -103,9 +101,7 @@ async def async_setup_entry(
 
 
 class TiltBluetoothSensorEntity(
-    PassiveBluetoothProcessorEntity[
-        PassiveBluetoothDataProcessor[Optional[Union[float, int]]]
-    ],
+    PassiveBluetoothProcessorEntity[PassiveBluetoothDataProcessor[float | int | None]],
     SensorEntity,
 ):
     """Representation of a Tilt Hydrometer BLE sensor."""
