@@ -2,8 +2,9 @@
 from __future__ import annotations
 
 import asyncio
-from typing import TYPE_CHECKING, Any, TypeVar
+from typing import TYPE_CHECKING, Any
 
+from typing_extensions import Self
 import zigpy.endpoint
 import zigpy.zcl.clusters.closures
 
@@ -36,8 +37,6 @@ if TYPE_CHECKING:
     from ...entity import ZhaEntity
     from ..device import ZHADevice
 
-_ChannelsT = TypeVar("_ChannelsT", bound="Channels")
-_ChannelPoolT = TypeVar("_ChannelPoolT", bound="ChannelPool")
 _ChannelsDictType = dict[str, base.ZigbeeChannel]
 
 
@@ -87,7 +86,7 @@ class Channels:
 
     @property
     def zha_device(self) -> ZHADevice:
-        """Return parent zha device."""
+        """Return parent ZHA device."""
         return self._zha_device
 
     @property
@@ -104,7 +103,7 @@ class Channels:
         }
 
     @classmethod
-    def new(cls: type[_ChannelsT], zha_device: ZHADevice) -> _ChannelsT:
+    def new(cls, zha_device: ZHADevice) -> Self:
         """Create new instance."""
         channels = cls(zha_device)
         for ep_id in sorted(zha_device.device.endpoints):
@@ -272,7 +271,7 @@ class ChannelPool:
         )
 
     @classmethod
-    def new(cls: type[_ChannelPoolT], channels: Channels, ep_id: int) -> _ChannelPoolT:
+    def new(cls, channels: Channels, ep_id: int) -> Self:
         """Create new channels for an endpoint."""
         pool = cls(channels, ep_id)
         pool.add_all_channels()
