@@ -4,8 +4,10 @@ from __future__ import annotations
 import enum
 import functools
 import numbers
-from typing import TYPE_CHECKING, Any, TypeVar
+import sys
+from typing import TYPE_CHECKING, Any
 
+from typing_extensions import Self
 from zigpy import types
 
 from homeassistant.components.climate import HVACAction
@@ -22,6 +24,7 @@ from homeassistant.const import (
     LIGHT_LUX,
     PERCENTAGE,
     SIGNAL_STRENGTH_DECIBELS_MILLIWATT,
+    EntityCategory,
     Platform,
     UnitOfApparentPower,
     UnitOfElectricCurrent,
@@ -38,7 +41,6 @@ from homeassistant.const import (
 )
 from homeassistant.core import HomeAssistant, callback
 from homeassistant.helpers.dispatcher import async_dispatcher_connect
-from homeassistant.helpers.entity import EntityCategory
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
 from homeassistant.helpers.typing import StateType
 
@@ -68,13 +70,6 @@ if TYPE_CHECKING:
     from .core.channels.base import ZigbeeChannel
     from .core.device import ZHADevice
 
-_SensorSelfT = TypeVar("_SensorSelfT", bound="Sensor")
-_BatterySelfT = TypeVar("_BatterySelfT", bound="Battery")
-_ThermostatHVACActionSelfT = TypeVar(
-    "_ThermostatHVACActionSelfT", bound="ThermostatHVACAction"
-)
-_RSSISensorSelfT = TypeVar("_RSSISensorSelfT", bound="RSSISensor")
-
 PARALLEL_UPDATES = 5
 
 BATTERY_SIZES = {
@@ -139,12 +134,12 @@ class Sensor(ZhaEntity, SensorEntity):
 
     @classmethod
     def create_entity(
-        cls: type[_SensorSelfT],
+        cls,
         unique_id: str,
         zha_device: ZHADevice,
         channels: list[ZigbeeChannel],
         **kwargs: Any,
-    ) -> _SensorSelfT | None:
+    ) -> Self | None:
         """Entity Factory.
 
         Return entity if it is a supported configuration, otherwise return None
@@ -209,12 +204,12 @@ class Battery(Sensor):
 
     @classmethod
     def create_entity(
-        cls: type[_BatterySelfT],
+        cls,
         unique_id: str,
         zha_device: ZHADevice,
         channels: list[ZigbeeChannel],
         **kwargs: Any,
-    ) -> _BatterySelfT | None:
+    ) -> Self | None:
         """Entity Factory.
 
         Unlike any other entity, PowerConfiguration cluster may not support
@@ -448,7 +443,12 @@ class SmartEnergyMetering(Sensor):
         if self._channel.device_type is not None:
             attrs["device_type"] = self._channel.device_type
         if (status := self._channel.status) is not None:
-            attrs["status"] = str(status)[len(status.__class__.__name__) + 1 :]
+            if isinstance(status, enum.IntFlag) and sys.version_info >= (3, 11):
+                attrs["status"] = str(
+                    status.name if status.name is not None else status.value
+                )
+            else:
+                attrs["status"] = str(status)[len(status.__class__.__name__) + 1 :]
         return attrs
 
 
@@ -710,12 +710,12 @@ class ThermostatHVACAction(Sensor, id_suffix="hvac_action"):
 
     @classmethod
     def create_entity(
-        cls: type[_ThermostatHVACActionSelfT],
+        cls,
         unique_id: str,
         zha_device: ZHADevice,
         channels: list[ZigbeeChannel],
         **kwargs: Any,
-    ) -> _ThermostatHVACActionSelfT | None:
+    ) -> Self | None:
         """Entity Factory.
 
         Return entity if it is a supported configuration, otherwise return None
@@ -839,12 +839,12 @@ class RSSISensor(Sensor, id_suffix="rssi"):
 
     @classmethod
     def create_entity(
-        cls: type[_RSSISensorSelfT],
+        cls,
         unique_id: str,
         zha_device: ZHADevice,
         channels: list[ZigbeeChannel],
         **kwargs: Any,
-    ) -> _RSSISensorSelfT | None:
+    ) -> Self | None:
         """Entity Factory.
 
         Return entity if it is a supported configuration, otherwise return None
