@@ -11,9 +11,11 @@ import functools
 import logging
 from random import randint
 from types import MappingProxyType, MethodType
-from typing import TYPE_CHECKING, Any, Optional, TypeVar, cast
+from typing import TYPE_CHECKING, Any, TypeVar, cast
 import weakref
 
+from typing_extensions import Self
+
 from . import data_entry_flow, loader
 from .backports.enum import StrEnum
 from .components import persistent_notification
@@ -63,14 +65,14 @@ SOURCE_USB = "usb"
 SOURCE_USER = "user"
 SOURCE_ZEROCONF = "zeroconf"
 
-# If a user wants to hide a discovery from the UI they can "Ignore" it. The config_entries/ignore_flow
-# websocket command creates a config entry with this source and while it exists normal discoveries
-# with the same unique id are ignored.
+# If a user wants to hide a discovery from the UI they can "Ignore" it. The
+# config_entries/ignore_flow websocket command creates a config entry with this
+# source and while it exists normal discoveries with the same unique id are ignored.
 SOURCE_IGNORE = "ignore"
 
 # This is used when a user uses the "Stop Ignoring" button in the UI (the
-# config_entries/ignore_flow websocket command). It's triggered after the "ignore" config entry has
-# been removed and unloaded.
+# config_entries/ignore_flow websocket command). It's triggered after the
+# "ignore" config entry has been removed and unloaded.
 SOURCE_UNIGNORE = "unignore"
 
 # This is used to signal that re-authentication is required by the user.
@@ -86,7 +88,6 @@ PATH_CONFIG = ".config_entries.json"
 
 SAVE_DELAY = 1
 
-_ConfigEntryStateSelfT = TypeVar("_ConfigEntryStateSelfT", bound="ConfigEntryState")
 _R = TypeVar("_R")
 
 
@@ -110,9 +111,7 @@ class ConfigEntryState(Enum):
 
     _recoverable: bool
 
-    def __new__(
-        cls: type[_ConfigEntryStateSelfT], value: str, recoverable: bool
-    ) -> _ConfigEntryStateSelfT:
+    def __new__(cls, value: str, recoverable: bool) -> Self:
         """Create new ConfigEntryState."""
         obj = object.__new__(cls)
         obj._value_ = value
@@ -221,7 +220,8 @@ class ConfigEntry:
         "_async_cancel_retry_setup",
         "_on_unload",
         "reload_lock",
-        "_pending_tasks",
+        "_tasks",
+        "_background_tasks",
     )
 
     def __init__(
@@ -316,7 +316,8 @@ class ConfigEntry:
         # Reload lock to prevent conflicting reloads
         self.reload_lock = asyncio.Lock()
 
-        self._pending_tasks: list[asyncio.Future[Any]] = []
+        self._tasks: set[asyncio.Future[Any]] = set()
+        self._background_tasks: set[asyncio.Future[Any]] = set()
 
     async def async_setup(
         self,
@@ -444,6 +445,10 @@ class ConfigEntry:
 
             async def setup_again(*_: Any) -> None:
                 """Run setup again."""
+                # Check again when we fire in case shutdown
+                # has started so we do not block shutdown
+                if hass.is_stopping:
+                    return
                 self._async_cancel_retry_setup = None
                 await self.async_setup(hass, integration=integration, tries=tries)
 
@@ -458,7 +463,8 @@ class ConfigEntry:
 
             await self._async_process_on_unload()
             return
-        except Exception:  # pylint: disable=broad-except
+        # pylint: disable-next=broad-except
+        except (asyncio.CancelledError, SystemExit, Exception):
             _LOGGER.exception(
                 "Error setting up entry %s for %s", self.title, integration.domain
             )
@@ -627,7 +633,7 @@ class ConfigEntry:
                 )
                 return False
             if result:
-                # pylint: disable=protected-access
+                # pylint: disable-next=protected-access
                 hass.config_entries._async_schedule_save()
             # https://github.com/python/mypy/issues/11839
             return result  # type: ignore[no-any-return]
@@ -643,7 +649,8 @@ class ConfigEntry:
         Returns function to unlisten.
         """
         weak_listener: Any
-        # weakref.ref is not applicable to a bound method, e.g. method of a class instance, as reference will die immediately
+        # weakref.ref is not applicable to a bound method, e.g.,
+        # method of a class instance, as reference will die immediately.
         if hasattr(listener, "__self__"):
             weak_listener = weakref.WeakMethod(cast(MethodType, listener))
         else:
@@ -681,11 +688,23 @@ class ConfigEntry:
             while self._on_unload:
                 self._on_unload.pop()()
 
-        while self._pending_tasks:
-            pending = [task for task in self._pending_tasks if not task.done()]
-            self._pending_tasks.clear()
-            if pending:
-                await asyncio.gather(*pending)
+        if not self._tasks and not self._background_tasks:
+            return
+
+        for task in self._background_tasks:
+            task.cancel()
+
+        _, pending = await asyncio.wait(
+            [*self._tasks, *self._background_tasks], timeout=10
+        )
+
+        for task in pending:
+            _LOGGER.warning(
+                "Unloading %s (%s) config entry. Task %s did not complete in time",
+                self.title,
+                self.domain,
+                task,
+            )
 
     @callback
     def async_start_reauth(
@@ -736,9 +755,24 @@ class ConfigEntry:
         target: target to call.
         """
         task = hass.async_create_task(target)
+        self._tasks.add(task)
+        task.add_done_callback(self._tasks.remove)
 
-        self._pending_tasks.append(task)
+        return task
 
+    @callback
+    def async_create_background_task(
+        self, hass: HomeAssistant, target: Coroutine[Any, Any, _R], name: str
+    ) -> asyncio.Task[_R]:
+        """Create a background task tied to the config entry lifecycle.
+
+        Background tasks are automatically canceled when config entry is unloaded.
+
+        target: target to call.
+        """
+        task = hass.async_create_background_task(target, name)
+        self._background_tasks.add(task)
+        task.add_done_callback(self._background_tasks.remove)
         return task
 
 
@@ -760,6 +794,15 @@ class ConfigEntriesFlowManager(data_entry_flow.FlowManager):
         super().__init__(hass)
         self.config_entries = config_entries
         self._hass_config = hass_config
+        self._pending_import_flows: dict[str, dict[str, asyncio.Future[None]]] = {}
+        self._initialize_tasks: dict[str, list[asyncio.Task]] = {}
+
+    async def async_wait_import_flow_initialized(self, handler: str) -> None:
+        """Wait till all import flows in progress are initialized."""
+        if not (current := self._pending_import_flows.get(handler)):
+            return
+
+        await asyncio.wait(current.values())
 
     @callback
     def _async_has_other_discovery_flows(self, flow_id: str) -> bool:
@@ -769,12 +812,77 @@ class ConfigEntriesFlowManager(data_entry_flow.FlowManager):
             for flow in self._progress.values()
         )
 
+    async def async_init(
+        self, handler: str, *, context: dict[str, Any] | None = None, data: Any = None
+    ) -> FlowResult:
+        """Start a configuration flow."""
+        if not context or "source" not in context:
+            raise KeyError("Context not set or doesn't have a source set")
+
+        flow_id = uuid_util.random_uuid_hex()
+        if context["source"] == SOURCE_IMPORT:
+            init_done: asyncio.Future[None] = asyncio.Future()
+            self._pending_import_flows.setdefault(handler, {})[flow_id] = init_done
+
+        task = asyncio.create_task(self._async_init(flow_id, handler, context, data))
+        self._initialize_tasks.setdefault(handler, []).append(task)
+
+        try:
+            flow, result = await task
+        finally:
+            self._initialize_tasks[handler].remove(task)
+            self._pending_import_flows.get(handler, {}).pop(flow_id, None)
+
+        if result["type"] != data_entry_flow.FlowResultType.ABORT:
+            await self.async_post_init(flow, result)
+
+        return result
+
+    async def _async_init(
+        self,
+        flow_id: str,
+        handler: str,
+        context: dict,
+        data: Any,
+    ) -> tuple[data_entry_flow.FlowHandler, FlowResult]:
+        """Run the init in a task to allow it to be canceled at shutdown."""
+        flow = await self.async_create_flow(handler, context=context, data=data)
+        if not flow:
+            raise data_entry_flow.UnknownFlow("Flow was not created")
+        flow.hass = self.hass
+        flow.handler = handler
+        flow.flow_id = flow_id
+        flow.context = context
+        flow.init_data = data
+        self._async_add_flow_progress(flow)
+        try:
+            result = await self._async_handle_step(flow, flow.init_step, data)
+        finally:
+            init_done = self._pending_import_flows.get(handler, {}).get(flow_id)
+            if init_done and not init_done.done():
+                init_done.set_result(None)
+        return flow, result
+
+    async def async_shutdown(self) -> None:
+        """Cancel any initializing flows."""
+        for task_list in self._initialize_tasks.values():
+            for task in task_list:
+                task.cancel()
+
     async def async_finish_flow(
         self, flow: data_entry_flow.FlowHandler, result: data_entry_flow.FlowResult
     ) -> data_entry_flow.FlowResult:
         """Finish a config flow and add an entry."""
         flow = cast(ConfigFlow, flow)
 
+        # Mark the step as done.
+        # We do this to avoid a circular dependency where async_finish_flow sets up a
+        # new entry, which needs the integration to be set up, which is waiting for
+        # init to be done.
+        init_done = self._pending_import_flows.get(flow.handler, {}).get(flow.flow_id)
+        if init_done and not init_done.done():
+            init_done.set_result(None)
+
         # Remove notification if no other discovery config entries in progress
         if not self._async_has_other_discovery_flows(flow.flow_id):
             persistent_notification.async_dismiss(self.hass, DISCOVERY_NOTIFICATION_ID)
@@ -994,10 +1102,10 @@ class ConfigEntries:
             ):
                 self.hass.config_entries.flow.async_abort(progress_flow["flow_id"])
 
-        # After we have fully removed an "ignore" config entry we can try and rediscover it so that a
-        # user is able to immediately start configuring it. We do this by starting a new flow with
-        # the 'unignore' step. If the integration doesn't implement async_step_unignore then
-        # this will be a no-op.
+        # After we have fully removed an "ignore" config entry we can try and rediscover
+        # it so that a user is able to immediately start configuring it. We do this by
+        # starting a new flow with the 'unignore' step. If the integration doesn't
+        # implement async_step_unignore then this will be a no-op.
         if entry.source == SOURCE_IGNORE:
             self.hass.async_create_task(
                 self.hass.config_entries.flow.async_init(
@@ -1040,7 +1148,8 @@ class ConfigEntries:
         for entry in config["entries"]:
             pref_disable_new_entities = entry.get("pref_disable_new_entities")
 
-            # Between 0.98 and 2021.6 we stored 'disable_new_entities' in a system options dictionary
+            # Between 0.98 and 2021.6 we stored 'disable_new_entities' in a
+            # system options dictionary.
             if pref_disable_new_entities is None and "system_options" in entry:
                 pref_disable_new_entities = entry.get("system_options", {}).get(
                     "disable_new_entities"
@@ -1100,7 +1209,9 @@ class ConfigEntries:
             if not result:
                 return result
 
-        return entry.state is ConfigEntryState.LOADED  # type: ignore[comparison-overlap] # mypy bug?
+        return (
+            entry.state is ConfigEntryState.LOADED  # type: ignore[comparison-overlap]
+        )
 
     async def async_unload(self, entry_id: str) -> bool:
         """Unload a config entry."""
@@ -1249,10 +1360,10 @@ class ConfigEntries:
         report(
             (
                 "called async_setup_platforms instead of awaiting"
-                " async_forward_entry_setups; this will fail in version 2022.12"
+                " async_forward_entry_setups; this will fail in version 2023.3"
             ),
             # Raise this to warning once all core integrations have been migrated
-            level=logging.DEBUG,
+            level=logging.WARNING,
             error_if_core=False,
         )
         for platform in platforms:
@@ -1359,7 +1470,7 @@ class ConfigFlow(data_entry_flow.FlowHandler):
         if not self.context:
             return None
 
-        return cast(Optional[str], self.context.get("unique_id"))
+        return cast(str | None, self.context.get("unique_id"))
 
     @staticmethod
     @callback
@@ -1377,12 +1488,19 @@ class ConfigFlow(data_entry_flow.FlowHandler):
     def _async_abort_entries_match(
         self, match_dict: dict[str, Any] | None = None
     ) -> None:
-        """Abort if current entries match all data."""
+        """Abort if current entries match all data.
+
+        Requires `already_configured` in strings.json in user visible flows.
+        """
         if match_dict is None:
             match_dict = {}  # Match any entry
         for entry in self._async_current_entries(include_ignore=False):
             if all(
-                item in ChainMap(entry.options, entry.data).items()  # type: ignore[arg-type]
+                item
+                in ChainMap(
+                    entry.options,  # type: ignore[arg-type]
+                    entry.data,  # type: ignore[arg-type]
+                ).items()
                 for item in match_dict.items()
             ):
                 raise data_entry_flow.AbortFlow("already_configured")
@@ -1395,7 +1513,11 @@ class ConfigFlow(data_entry_flow.FlowHandler):
         *,
         error: str = "already_configured",
     ) -> None:
-        """Abort if the unique ID is already configured."""
+        """Abort if the unique ID is already configured.
+
+        Requires strings.json entry corresponding to the `error` parameter
+        in user visible flows.
+        """
         if self.unique_id is None:
             return
 
@@ -1474,7 +1596,8 @@ class ConfigFlow(data_entry_flow.FlowHandler):
     ) -> list[ConfigEntry]:
         """Return current entries.
 
-        If the flow is user initiated, filter out ignored entries unless include_ignore is True.
+        If the flow is user initiated, filter out ignored entries,
+        unless include_ignore is True.
         """
         config_entries = self.hass.config_entries.async_entries(self.handler)
 
@@ -1536,6 +1659,9 @@ class ConfigFlow(data_entry_flow.FlowHandler):
         when the handler has no existing config entries.
 
         It ensures that the discovery can be ignored by the user.
+
+        Requires `already_configured` and `already_in_progress` in strings.json
+        in user visible flows.
         """
         if self.unique_id is not None:
             return
@@ -1737,7 +1863,7 @@ class OptionsFlowWithConfigEntry(OptionsFlow):
 
 
 class EntityRegistryDisabledHandler:
-    """Handler to handle when entities related to config entries updating disabled_by."""
+    """Handler when entities related to config entries updated disabled_by."""
 
     def __init__(self, hass: HomeAssistant) -> None:
         """Initialize the handler."""
