@@ -268,8 +268,7 @@ class TemplateEntity(Entity):
         on_update: Callable[[Any], None] | None = None,
         none_on_template_error: bool = False,
     ) -> None:
-        """
-        Call in the constructor to add a template linked to a attribute.
+        """Call in the constructor to add a template linked to a attribute.
 
         Parameters
         ----------
@@ -284,6 +283,8 @@ class TemplateEntity(Entity):
             Called to store the template result rather than storing it
             the supplied attribute. Passed the result of the validator, or None
             if the template or validator resulted in an error.
+        none_on_template_error
+            If True, the attribute will be set to None if the template errors.
 
         """
         assert self.hass is not None, "hass cannot be None"
