@@ -2,6 +2,7 @@
 from __future__ import annotations
 
 from homeassistant.const import (
+    PERCENTAGE,
     UNIT_NOT_RECOGNIZED_TEMPLATE,
     UnitOfDataRate,
     UnitOfElectricCurrent,
@@ -56,13 +57,13 @@ class BaseUnitConverter:
     """Define the format of a conversion utility."""
 
     UNIT_CLASS: str
-    NORMALIZED_UNIT: str
-    VALID_UNITS: set[str]
+    NORMALIZED_UNIT: str | None
+    VALID_UNITS: set[str | None]
 
-    _UNIT_CONVERSION: dict[str, float]
+    _UNIT_CONVERSION: dict[str | None, float]
 
     @classmethod
-    def convert(cls, value: float, from_unit: str, to_unit: str) -> float:
+    def convert(cls, value: float, from_unit: str | None, to_unit: str | None) -> float:
         """Convert one unit of measurement to another."""
         if from_unit == to_unit:
             return value
@@ -85,7 +86,7 @@ class BaseUnitConverter:
         return new_value * to_ratio
 
     @classmethod
-    def get_unit_ratio(cls, from_unit: str, to_unit: str) -> float:
+    def get_unit_ratio(cls, from_unit: str | None, to_unit: str | None) -> float:
         """Get unit ratio between units of measurement."""
         return cls._UNIT_CONVERSION[from_unit] / cls._UNIT_CONVERSION[to_unit]
 
@@ -96,7 +97,7 @@ class DataRateConverter(BaseUnitConverter):
     UNIT_CLASS = "data_rate"
     NORMALIZED_UNIT = UnitOfDataRate.BITS_PER_SECOND
     # Units in terms of bits
-    _UNIT_CONVERSION: dict[str, float] = {
+    _UNIT_CONVERSION: dict[str | None, float] = {
         UnitOfDataRate.BITS_PER_SECOND: 1,
         UnitOfDataRate.KILOBITS_PER_SECOND: 1 / 1e3,
         UnitOfDataRate.MEGABITS_PER_SECOND: 1 / 1e6,
@@ -117,7 +118,7 @@ class DistanceConverter(BaseUnitConverter):
 
     UNIT_CLASS = "distance"
     NORMALIZED_UNIT = UnitOfLength.METERS
-    _UNIT_CONVERSION: dict[str, float] = {
+    _UNIT_CONVERSION: dict[str | None, float] = {
         UnitOfLength.METERS: 1,
         UnitOfLength.MILLIMETERS: 1 / _MM_TO_M,
         UnitOfLength.CENTIMETERS: 1 / _CM_TO_M,
@@ -144,7 +145,7 @@ class ElectricCurrentConverter(BaseUnitConverter):
 
     UNIT_CLASS = "electric_current"
     NORMALIZED_UNIT = UnitOfElectricCurrent.AMPERE
-    _UNIT_CONVERSION: dict[str, float] = {
+    _UNIT_CONVERSION: dict[str | None, float] = {
         UnitOfElectricCurrent.AMPERE: 1,
         UnitOfElectricCurrent.MILLIAMPERE: 1e3,
     }
@@ -156,7 +157,7 @@ class ElectricPotentialConverter(BaseUnitConverter):
 
     UNIT_CLASS = "voltage"
     NORMALIZED_UNIT = UnitOfElectricPotential.VOLT
-    _UNIT_CONVERSION: dict[str, float] = {
+    _UNIT_CONVERSION: dict[str | None, float] = {
         UnitOfElectricPotential.VOLT: 1,
         UnitOfElectricPotential.MILLIVOLT: 1e3,
     }
@@ -171,16 +172,18 @@ class EnergyConverter(BaseUnitConverter):
 
     UNIT_CLASS = "energy"
     NORMALIZED_UNIT = UnitOfEnergy.KILO_WATT_HOUR
-    _UNIT_CONVERSION: dict[str, float] = {
+    _UNIT_CONVERSION: dict[str | None, float] = {
         UnitOfEnergy.WATT_HOUR: 1 * 1000,
         UnitOfEnergy.KILO_WATT_HOUR: 1,
         UnitOfEnergy.MEGA_WATT_HOUR: 1 / 1000,
+        UnitOfEnergy.MEGA_JOULE: 3.6,
         UnitOfEnergy.GIGA_JOULE: 3.6 / 1000,
     }
     VALID_UNITS = {
         UnitOfEnergy.WATT_HOUR,
         UnitOfEnergy.KILO_WATT_HOUR,
         UnitOfEnergy.MEGA_WATT_HOUR,
+        UnitOfEnergy.MEGA_JOULE,
         UnitOfEnergy.GIGA_JOULE,
     }
 
@@ -191,7 +194,7 @@ class InformationConverter(BaseUnitConverter):
     UNIT_CLASS = "information"
     NORMALIZED_UNIT = UnitOfInformation.BITS
     # Units in terms of bits
-    _UNIT_CONVERSION: dict[str, float] = {
+    _UNIT_CONVERSION: dict[str | None, float] = {
         UnitOfInformation.BITS: 1,
         UnitOfInformation.KILOBITS: 1 / 1e3,
         UnitOfInformation.MEGABITS: 1 / 1e6,
@@ -222,7 +225,7 @@ class MassConverter(BaseUnitConverter):
 
     UNIT_CLASS = "mass"
     NORMALIZED_UNIT = UnitOfMass.GRAMS
-    _UNIT_CONVERSION: dict[str, float] = {
+    _UNIT_CONVERSION: dict[str | None, float] = {
         UnitOfMass.MICROGRAMS: 1 * 1000 * 1000,
         UnitOfMass.MILLIGRAMS: 1 * 1000,
         UnitOfMass.GRAMS: 1,
@@ -247,7 +250,7 @@ class PowerConverter(BaseUnitConverter):
 
     UNIT_CLASS = "power"
     NORMALIZED_UNIT = UnitOfPower.WATT
-    _UNIT_CONVERSION: dict[str, float] = {
+    _UNIT_CONVERSION: dict[str | None, float] = {
         UnitOfPower.WATT: 1,
         UnitOfPower.KILO_WATT: 1 / 1000,
     }
@@ -262,7 +265,7 @@ class PressureConverter(BaseUnitConverter):
 
     UNIT_CLASS = "pressure"
     NORMALIZED_UNIT = UnitOfPressure.PA
-    _UNIT_CONVERSION: dict[str, float] = {
+    _UNIT_CONVERSION: dict[str | None, float] = {
         UnitOfPressure.PA: 1,
         UnitOfPressure.HPA: 1 / 100,
         UnitOfPressure.KPA: 1 / 1000,
@@ -293,7 +296,7 @@ class SpeedConverter(BaseUnitConverter):
 
     UNIT_CLASS = "speed"
     NORMALIZED_UNIT = UnitOfSpeed.METERS_PER_SECOND
-    _UNIT_CONVERSION: dict[str, float] = {
+    _UNIT_CONVERSION: dict[str | None, float] = {
         UnitOfVolumetricFlux.INCHES_PER_DAY: _DAYS_TO_SECS / _IN_TO_M,
         UnitOfVolumetricFlux.INCHES_PER_HOUR: _HRS_TO_SECS / _IN_TO_M,
         UnitOfVolumetricFlux.MILLIMETERS_PER_DAY: _DAYS_TO_SECS / _MM_TO_M,
@@ -334,7 +337,7 @@ class TemperatureConverter(BaseUnitConverter):
     }
 
     @classmethod
-    def convert(cls, value: float, from_unit: str, to_unit: str) -> float:
+    def convert(cls, value: float, from_unit: str | None, to_unit: str | None) -> float:
         """Convert a temperature from one unit to another.
 
         eg. 10°C will return 50°F
@@ -342,8 +345,8 @@ class TemperatureConverter(BaseUnitConverter):
         For converting an interval between two temperatures, please use
         `convert_interval` instead.
         """
-        # We cannot use the implementation from BaseUnitConverter here because the temperature
-        # units do not use the same floor: 0°C, 0°F and 0K do not align
+        # We cannot use the implementation from BaseUnitConverter here because the
+        # temperature units do not use the same floor: 0°C, 0°F and 0K do not align
         if from_unit == to_unit:
             return value
 
@@ -411,13 +414,28 @@ class TemperatureConverter(BaseUnitConverter):
         return celsius + 273.15
 
 
+class UnitlessRatioConverter(BaseUnitConverter):
+    """Utility to convert unitless ratios."""
+
+    UNIT_CLASS = "unitless"
+    NORMALIZED_UNIT = None
+    _UNIT_CONVERSION: dict[str | None, float] = {
+        None: 1,
+        PERCENTAGE: 100,
+    }
+    VALID_UNITS = {
+        None,
+        PERCENTAGE,
+    }
+
+
 class VolumeConverter(BaseUnitConverter):
     """Utility to convert volume values."""
 
     UNIT_CLASS = "volume"
     NORMALIZED_UNIT = UnitOfVolume.CUBIC_METERS
     # Units in terms of m³
-    _UNIT_CONVERSION: dict[str, float] = {
+    _UNIT_CONVERSION: dict[str | None, float] = {
         UnitOfVolume.LITERS: 1 / _L_TO_CUBIC_METER,
         UnitOfVolume.MILLILITERS: 1 / _ML_TO_CUBIC_METER,
         UnitOfVolume.GALLONS: 1 / _GALLON_TO_CUBIC_METER,
